@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -43,17 +44,17 @@
 
 */
 
-#include <visp3/core/vpDebug.h>
-#include <visp3/core/vpConfig.h>
 #include <stdlib.h>
+#include <visp3/core/vpConfig.h>
+#include <visp3/core/vpDebug.h>
 
 #if defined(VISP_HAVE_OPENCV)
 
 #include <visp3/core/vpImage.h>
-#include <visp3/io/vpImageIo.h>
-#include <visp3/gui/vpDisplayOpenCV.h>
-#include <visp3/io/vpParseArgv.h>
 #include <visp3/core/vpIoTools.h>
+#include <visp3/gui/vpDisplayOpenCV.h>
+#include <visp3/io/vpImageIo.h>
+#include <visp3/io/vpParseArgv.h>
 
 #include <visp3/core/vpTime.h>
 
@@ -67,11 +68,7 @@
 */
 
 // List of allowed command line options
-#define GETOPTARGS	"cdi:o:p:h"
-
-void usage(const char *name, const char *badparam, std::string ipath, std::string opath, std::string user);
-bool getOptions(int argc, const char **argv, std::string &ipath, std::string &opath,
-                bool &click_allowed, std::string user, bool &display);
+#define GETOPTARGS "cdi:o:p:h"
 
 /*!
 
@@ -100,7 +97,7 @@ SYNOPSIS\n\
 OPTIONS:                                               Default\n\
   -i <input image path>                                %s\n\
      Set image input path.\n\
-     From this path read \"ViSP-images/Klimt/Klimt.pgm\"\n\
+     From this path read \"Klimt/Klimt.pgm\"\n\
      image.\n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
      variable produces the same behaviour than using\n\
@@ -122,14 +119,12 @@ OPTIONS:                                               Default\n\
      using the task manager under Windows.\n\
 \n\
   -h\n\
-     Print the help.\n\n",
-	  ipath.c_str(), opath.c_str(), user.c_str());
+     Print the help.\n\n", ipath.c_str(), opath.c_str(), user.c_str());
 
   if (badparam) {
-    fprintf(stderr, "ERROR: \n" );
+    fprintf(stderr, "ERROR: \n");
     fprintf(stderr, "\nBad parameter [%s]\n", badparam);
   }
-
 }
 
 /*!
@@ -150,22 +145,35 @@ OPTIONS:                                               Default\n\
   \return false if the program has to be stopped, true otherwise.
 
 */
-bool getOptions(int argc, const char **argv, std::string &ipath, std::string &opath,
-                bool &click_allowed, std::string user, bool &display)
+bool getOptions(int argc, const char **argv, std::string &ipath, std::string &opath, bool &click_allowed,
+                const std::string &user, bool &display)
 {
   const char *optarg_;
-  int	c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg_)) > 1) {
 
     switch (c) {
-    case 'c': click_allowed = false; break;
-    case 'd': display = false; break;
-    case 'i': ipath = optarg_; break;
-    case 'o': opath = optarg_; break;
-    case 'h': usage(argv[0], NULL, ipath, opath, user); return false; break;
+    case 'c':
+      click_allowed = false;
+      break;
+    case 'd':
+      display = false;
+      break;
+    case 'i':
+      ipath = optarg_;
+      break;
+    case 'o':
+      opath = optarg_;
+      break;
+    case 'h':
+      usage(argv[0], NULL, ipath, opath, user);
+      return false;
+      break;
 
     default:
-      usage(argv[0], optarg_, ipath, opath, user); return false; break;
+      usage(argv[0], optarg_, ipath, opath, user);
+      return false;
+      break;
     }
   }
 
@@ -180,8 +188,7 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &op
   return true;
 }
 
-int
-main(int argc, const char ** argv)
+int main(int argc, const char **argv)
 {
   try {
     std::string env_ipath;
@@ -194,14 +201,15 @@ main(int argc, const char ** argv)
     bool opt_click_allowed = true;
     bool opt_display = true;
 
-    // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH environment variable value
+    // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH
+    // environment variable value
     env_ipath = vpIoTools::getViSPImagesDataPath();
 
     // Set the default input path
-    if (! env_ipath.empty())
+    if (!env_ipath.empty())
       ipath = env_ipath;
 
-    // Set the default output path
+// Set the default output path
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
     opt_opath = "/tmp";
 #elif defined(_WIN32)
@@ -212,9 +220,8 @@ main(int argc, const char ** argv)
     vpIoTools::getUserName(username);
 
     // Read the command line options
-    if (getOptions(argc, argv, opt_ipath, opt_opath,
-                   opt_click_allowed, username, opt_display) == false) {
-      exit (-1);
+    if (getOptions(argc, argv, opt_ipath, opt_opath, opt_click_allowed, username, opt_display) == false) {
+      exit(-1);
     }
 
     // Get the option values
@@ -231,11 +238,9 @@ main(int argc, const char ** argv)
       try {
         // Create the dirname
         vpIoTools::makeDirectory(odirname);
-      }
-      catch (...) {
+      } catch (...) {
         usage(argv[0], NULL, ipath, opath, username);
-        std::cerr << std::endl
-                  << "ERROR:" << std::endl;
+        std::cerr << std::endl << "ERROR:" << std::endl;
         std::cerr << "  Cannot create " << odirname << std::endl;
         std::cerr << "  Check your -o " << opath << " option " << std::endl;
         exit(-1);
@@ -246,8 +251,7 @@ main(int argc, const char ** argv)
     // the input path comming from the command line option
     if (!opt_ipath.empty() && !env_ipath.empty()) {
       if (ipath != env_ipath) {
-        std::cout << std::endl
-                  << "WARNING: " << std::endl;
+        std::cout << std::endl << "WARNING: " << std::endl;
         std::cout << "  Since -i <visp image path=" << ipath << "> "
                   << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
                   << "  we skip the environment variable." << std::endl;
@@ -255,24 +259,23 @@ main(int argc, const char ** argv)
     }
 
     // Test if an input path is set
-    if (opt_ipath.empty() && env_ipath.empty()){
+    if (opt_ipath.empty() && env_ipath.empty()) {
       usage(argv[0], NULL, ipath, opath, username);
-      std::cerr << std::endl
-                << "ERROR:" << std::endl;
-      std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH "
-                << std::endl
+      std::cerr << std::endl << "ERROR:" << std::endl;
+      std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
                 << "  environment variable to specify the location of the " << std::endl
-                << "  image path where test images are located." << std::endl << std::endl;
+                << "  image path where test images are located." << std::endl
+                << std::endl;
       exit(-1);
     }
 
     // Create a grey level image
-    vpImage<unsigned char> I ;
+    vpImage<unsigned char> I;
     vpImagePoint ip, ip1, ip2;
 
     // Load a grey image from the disk
-    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.pgm");
-    vpImageIo::read(I, filename) ;
+    filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.pgm");
+    vpImageIo::read(I, filename);
 
     // Create a display using X11
     vpDisplayOpenCV display;
@@ -280,92 +283,91 @@ main(int argc, const char ** argv)
     if (opt_display) {
       // For this grey level image, open a X11 display at position 100,100
       // in the screen, and with title "X11 display"
-      display.init(I, 100, 100, "X11 display") ;
+      display.init(I, 100, 100, "X11 display");
 
       // Display the image
-      vpDisplay::display(I) ;
+      vpDisplay::display(I);
 
       // Display in overlay a red cross at position 10,10 in the
       // image. The lines are 10 pixels long
-      ip.set_i( 100 );
-      ip.set_j( 10 );
+      ip.set_i(100);
+      ip.set_j(10);
 
-      vpDisplay::displayCross(I, ip, 20, vpColor::red) ;
+      vpDisplay::displayCross(I, ip, 20, vpColor::red);
 
       // Display in overlay horizontal red lines
-      for (unsigned i=0 ; i < I.getHeight() ; i+=20) {
-        ip1.set_i( i );
-        ip1.set_j( 0 );
-        ip2.set_i( i );
-        ip2.set_j( I.getWidth() );
-        vpDisplay::displayLine(I, ip1, ip2, vpColor::red) ;
+      for (unsigned i = 0; i < I.getHeight(); i += 20) {
+        ip1.set_i(i);
+        ip1.set_j(0);
+        ip2.set_i(i);
+        ip2.set_j(I.getWidth());
+        vpDisplay::displayLine(I, ip1, ip2, vpColor::red);
       }
 
       // Display a ligne in the diagonal
-      ip1.set_i( -10 );
-      ip1.set_j( -10 );
-      ip2.set_i( I.getHeight() + 10 );
-      ip2.set_j( I.getWidth()  + 10 );
+      ip1.set_i(-10);
+      ip1.set_j(-10);
+      ip2.set_i(I.getHeight() + 10);
+      ip2.set_j(I.getWidth() + 10);
 
-      vpDisplay::displayLine(I, ip1, ip2, vpColor::red) ;
+      vpDisplay::displayLine(I, ip1, ip2, vpColor::red);
 
       // Display in overlay vertical green dot lines
-      for (unsigned i=0 ; i < I.getWidth() ; i+=20) {
-        ip1.set_i( 0 );
-        ip1.set_j( i );
-        ip2.set_i( I.getWidth() );
-        ip2.set_j( i );
-        vpDisplay::displayDotLine(I, ip1, ip2, vpColor::green) ;
+      for (unsigned i = 0; i < I.getWidth(); i += 20) {
+        ip1.set_i(0);
+        ip1.set_j(i);
+        ip2.set_i(I.getWidth());
+        ip2.set_j(i);
+        vpDisplay::displayDotLine(I, ip1, ip2, vpColor::green);
       }
 
       // Display a rectangle
-      ip.set_i( I.getHeight() - 45 );
-      ip.set_j( -10 );
-      vpDisplay::displayRectangle(I, ip, 60, 80, vpColor::orange) ;
+      ip.set_i(I.getHeight() - 45);
+      ip.set_j(-10);
+      vpDisplay::displayRectangle(I, ip, 60, 80, vpColor::orange);
 
       // Display in overlay a blue arrow
-      ip1.set_i( 0 );
-      ip1.set_j( 0 );
-      ip2.set_i( 100 );
-      ip2.set_j( 100 );
-      vpDisplay::displayArrow(I, ip1, ip2, vpColor::blue) ;
+      ip1.set_i(0);
+      ip1.set_j(0);
+      ip2.set_i(100);
+      ip2.set_j(100);
+      vpDisplay::displayArrow(I, ip1, ip2, vpColor::blue);
 
-      // Display in overlay some circles. The position of the center is 200, 200
-      // the radius is increased by 20 pixels for each circle
+      // Display in overlay some circles. The position of the center is 200,
+      // 200 the radius is increased by 20 pixels for each circle
 
-      for (unsigned int i=0 ; i < 100 ; i+=20) {
-        ip.set_i( 80 );
-        ip.set_j( 80 );
-        vpDisplay::displayCircle(I, ip, 20+i, vpColor::yellow) ;
+      for (unsigned int i = 0; i < 100; i += 20) {
+        ip.set_i(80);
+        ip.set_j(80);
+        vpDisplay::displayCircle(I, ip, 20 + i, vpColor::yellow);
       }
 
-      ip.set_i( -10 );
-      ip.set_j( 300 );
-      vpDisplay::displayCircle(I, ip, 100,vpColor::yellow) ;
+      ip.set_i(-10);
+      ip.set_j(300);
+      vpDisplay::displayCircle(I, ip, 100, vpColor::yellow);
 
       // Display in overlay a yellow string
-      ip.set_i( 85 );
-      ip.set_j( 100 );
-      vpDisplay::displayText(I, ip,
-                             "ViSP is a marvelous software",
-                             vpColor::yellow) ;
-      //Flush the display
+      ip.set_i(85);
+      ip.set_j(100);
+      vpDisplay::displayText(I, ip, "ViSP is a marvelous software", vpColor::yellow);
+      // Flush the display
       vpDisplay::flush(I);
 
       // Create a color image
-      vpImage<vpRGBa> Ioverlay ;
-      // Updates the color image with the original loaded image and the overlay
-      vpDisplay::getImage(I, Ioverlay) ;
+      vpImage<vpRGBa> Ioverlay;
+      // Updates the color image with the original loaded image and the
+      // overlay
+      vpDisplay::getImage(I, Ioverlay);
 
       // Write the color image on the disk
       filename = vpIoTools::createFilePath(odirname, "Klimt_grey.overlay.ppm");
-      vpImageIo::write(Ioverlay, filename) ;
+      vpImageIo::write(Ioverlay, filename);
 
       // If click is allowed, wait for a mouse click to close the display
       if (opt_click_allowed) {
         std::cout << "\nA click to close the windows..." << std::endl;
         // Wait for a blocking mouse click
-        vpDisplay::getClick(I) ;
+        vpDisplay::getClick(I);
       }
 
       // Close the display
@@ -373,11 +375,11 @@ main(int argc, const char ** argv)
     }
 
     // Create a color image
-    vpImage<vpRGBa> Irgba ;
+    vpImage<vpRGBa> Irgba;
 
     // Load a grey image from the disk and convert it to a color image
-    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.ppm");
-    vpImageIo::read(Irgba, filename) ;
+    filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.ppm");
+    vpImageIo::read(Irgba, filename);
 
     // Create a new display
     vpDisplayOpenCV displayRGBa;
@@ -388,62 +390,56 @@ main(int argc, const char ** argv)
       displayRGBa.init(Irgba, 100, 100, "X11 color display");
 
       // Display the color image
-      vpDisplay::display(Irgba) ;
-      vpDisplay::flush(Irgba) ;
+      vpDisplay::display(Irgba);
+      vpDisplay::flush(Irgba);
 
-      // If click is allowed, wait for a blocking mouse click to display a cross
-      // at the clicked pixel position
+      // If click is allowed, wait for a blocking mouse click to display a
+      // cross at the clicked pixel position
       if (opt_click_allowed) {
         std::cout << "\nA click to display a cross..." << std::endl;
         // Blocking wait for a click. Get the position of the selected pixel
-        // (i correspond to the row and j to the column coordinates in the image)
+        // (i correspond to the row and j to the column coordinates in the
+        // image)
         vpDisplay::getClick(Irgba, ip);
         // Display a red cross on the click pixel position
         std::cout << "Cross position: " << ip << std::endl;
         vpDisplay::displayCross(Irgba, ip, 15, vpColor::red);
-      }
-      else {
-        ip.set_i( 10 );
-        ip.set_j( 20 );
+      } else {
+        ip.set_i(10);
+        ip.set_j(20);
         // Display a red cross at position i, j (i correspond to the row
         // and j to the column coordinates in the image)
         std::cout << "Cross position: " << ip << std::endl;
         vpDisplay::displayCross(Irgba, ip, 15, vpColor::red);
-
       }
       // Flush the display. Sometimes the display content is
       // bufferized. Force to display the content that has been bufferized.
       vpDisplay::flush(Irgba);
 
       // Create a color image
-      vpImage<vpRGBa> Ioverlay ;
-      // Updates the color image with the original loaded image and the overlay
-      vpDisplay::getImage(Irgba, Ioverlay) ;
+      vpImage<vpRGBa> Ioverlay;
+      // Updates the color image with the original loaded image and the
+      // overlay
+      vpDisplay::getImage(Irgba, Ioverlay);
 
       // Write the color image on the disk
       filename = vpIoTools::createFilePath(odirname, "Klimt_color.overlay.ppm");
-      vpImageIo::write(Ioverlay, filename) ;
+      vpImageIo::write(Ioverlay, filename);
 
       // If click is allowed, wait for a blocking mouse click to exit.
       if (opt_click_allowed) {
         std::cout << "\nA click to exit the program..." << std::endl;
-        vpDisplay::getClick(Irgba) ;
+        vpDisplay::getClick(Irgba);
         std::cout << "Bye" << std::endl;
       }
     }
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return 1;
   }
 }
 #else
-int
-main()
-{
-  vpERROR_TRACE("You do not have OpenCV functionalities to display images...");
-}
+int main() { vpERROR_TRACE("You do not have OpenCV functionalities to display images..."); }
 
 #endif
-
