@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -50,16 +51,15 @@
 
 #if defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100)
 
-#include <visp3/gui/vpDisplayOpenCV.h>
 #include <visp3/core/vpImage.h>
 #include <visp3/core/vpImageConvert.h>
+#include <visp3/gui/vpDisplayOpenCV.h>
 #include <visp3/sensor/vpOpenCVGrabber.h>
 
-
 // usage: binary <device name>
-// device name: 0 is the default to dial with the first camera, 
+// device name: 0 is the default to dial with the first camera,
 //              1 to dial with a second camera attached to the computer
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
   try {
     int device = 0;
@@ -75,28 +75,27 @@ int main(int argc, char** argv)
     cap.set(CV_CAP_PROP_FRAME_WIDTH, 640);
     cap.set(CV_CAP_PROP_FRAME_HEIGHT, 480);
 #endif
-    if(!cap.isOpened())  // check if we succeeded
+    if (!cap.isOpened()) // check if we succeeded
       return -1;
     cv::Mat frame;
-    int i=0;
-    while ((i++ < 100) && !cap.read(frame)) {}; // warm up camera by skiping unread frames
+    int i = 0;
+    while ((i++ < 100) && !cap.read(frame)) {
+    }; // warm up camera by skiping unread frames
 
     std::cout << "Image size: "
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
-              << (int)cap.get(cv::CAP_PROP_FRAME_WIDTH) << " "
-              << (int)cap.get(cv::CAP_PROP_FRAME_HEIGHT) << std::endl;
+              << (int)cap.get(cv::CAP_PROP_FRAME_WIDTH) << " " << (int)cap.get(cv::CAP_PROP_FRAME_HEIGHT) << std::endl;
 #else
-              << (int)cap.get(CV_CAP_PROP_FRAME_WIDTH) << " "
-              << (int)cap.get(CV_CAP_PROP_FRAME_HEIGHT) << std::endl;
+              << (int)cap.get(CV_CAP_PROP_FRAME_WIDTH) << " " << (int)cap.get(CV_CAP_PROP_FRAME_HEIGHT) << std::endl;
 #endif
 
-    //vpImage<vpRGBa> I; // for color images
+    // vpImage<vpRGBa> I; // for color images
     vpImage<unsigned char> I; // for gray images
     vpImageConvert::convert(frame, I);
 
     vpDisplayOpenCV d(I);
 
-    for(;;) {
+    for (;;) {
       cap >> frame; // get a new frame from camera
 
       // Convert the image in ViSP format and display it
@@ -106,19 +105,16 @@ int main(int argc, char** argv)
       if (vpDisplay::getClick(I, false)) // a click to exit
         break;
     }
-    // the camera will be deinitialized automatically in VideoCapture destructor
+    // the camera will be deinitialized automatically in VideoCapture
+    // destructor
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return 1;
   }
 }
 
 #else
-int main()
-{
-  std::cout << "OpenCV is not available..." << std::endl;
-}
+int main() { std::cout << "OpenCV is not available..." << std::endl; }
 
 #endif
