@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -36,10 +37,9 @@
  *
  *****************************************************************************/
 
-
+#include <stdlib.h>
 #include <visp3/core/vpConfig.h>
 #include <visp3/core/vpDebug.h>
-#include <stdlib.h>
 /*!
   \file grabV4l2.cpp
 
@@ -49,19 +49,19 @@
 
 #ifdef VISP_HAVE_V4L2
 
-#if (defined (VISP_HAVE_X11) || defined(VISP_HAVE_GTK))
+#if (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK))
 
 #include <visp3/core/vpDisplay.h>
-#include <visp3/gui/vpDisplayX.h>
-#include <visp3/gui/vpDisplayGTK.h>
 #include <visp3/core/vpImage.h>
-#include <visp3/io/vpImageIo.h>
 #include <visp3/core/vpTime.h>
+#include <visp3/gui/vpDisplayGTK.h>
+#include <visp3/gui/vpDisplayX.h>
+#include <visp3/io/vpImageIo.h>
 #include <visp3/io/vpParseArgv.h>
 #include <visp3/sensor/vpV4l2Grabber.h>
 
 // List of allowed command line options
-#define GETOPTARGS	"df:i:hn:o:p:s:t:v:x"
+#define GETOPTARGS "df:i:hn:o:p:s:t:v:x"
 
 typedef enum {
   grey_image = 0, // for ViSP unsigned char grey images
@@ -84,10 +84,9 @@ typedef enum {
   \param opath : Image filename when saving.
 
 */
-void usage(const char *name, const char *badparam, unsigned fps, 
-	   unsigned input, unsigned scale, long niter, char *device, 
-	   vpV4l2Grabber::vpV4l2PixelFormatType pixelformat, 
-     const vpImage_type &image_type, const std::string &opath)
+void usage(const char *name, const char *badparam, unsigned fps, unsigned input, unsigned scale, long niter,
+           char *device, vpV4l2Grabber::vpV4l2PixelFormatType pixelformat, const vpImage_type &image_type,
+           const std::string &opath)
 {
   fprintf(stdout, "\n\
 Grab grey level images using the Video For Linux Two framegrabber. \n\
@@ -145,9 +144,8 @@ OPTIONS:                                                  Default\n\
      by the extension of the file (ex .png, .pgm, ...) \n\
                     \n\
   -h \n\
-     Print the help.\n\n",
-	  device, fps, input, pixelformat, 
-    vpV4l2Grabber::V4L2_MAX_FORMAT-1, image_type, scale, niter, opath.c_str());
+     Print the help.\n\n", device, fps, input, pixelformat, vpV4l2Grabber::V4L2_MAX_FORMAT - 1, image_type, scale, niter,
+          opath.c_str());
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -174,43 +172,61 @@ OPTIONS:                                                  Default\n\
   \return false if the program has to be stopped, true otherwise.
 
 */
-bool getOptions(int argc, const char **argv, unsigned &fps, unsigned &input,
-                unsigned &scale, bool &display, bool &verbose,
-                long &niter, char *device,
-                vpV4l2Grabber::vpV4l2PixelFormatType &pixelformat,
+bool getOptions(int argc, const char **argv, unsigned &fps, unsigned &input, unsigned &scale, bool &display,
+                bool &verbose, long &niter, char *device, vpV4l2Grabber::vpV4l2PixelFormatType &pixelformat,
                 vpImage_type &image_type, bool &save, std::string &opath)
 {
   const char *optarg_;
-  int	c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg_)) > 1) {
 
     switch (c) {
-    case 'd': display = false; break;
-    case 'f': fps = (unsigned) atoi(optarg_); break;
-    case 'i': input = (unsigned) atoi(optarg_); break;
-    case 'n': niter = atol(optarg_); break;
+    case 'd':
+      display = false;
+      break;
+    case 'f':
+      fps = (unsigned)atoi(optarg_);
+      break;
+    case 'i':
+      input = (unsigned)atoi(optarg_);
+      break;
+    case 'n':
+      niter = atol(optarg_);
+      break;
     case 'o':
       save = true;
-      opath = optarg_; break;
-    case 'p': pixelformat = (vpV4l2Grabber::vpV4l2PixelFormatType) atoi(optarg_); break;
-    case 's': scale = (unsigned) atoi(optarg_); break;
-    case 't': image_type = (vpImage_type) atoi(optarg_); break;
-    case 'v': sprintf(device, "%s", optarg_); break;
-    case 'x': verbose = true; break;
-    case 'h': usage(argv[0], NULL, fps, input, scale, niter, 
-                    device, pixelformat, image_type, opath);
-      return false; break;
+      opath = optarg_;
+      break;
+    case 'p':
+      pixelformat = (vpV4l2Grabber::vpV4l2PixelFormatType)atoi(optarg_);
+      break;
+    case 's':
+      scale = (unsigned)atoi(optarg_);
+      break;
+    case 't':
+      image_type = (vpImage_type)atoi(optarg_);
+      break;
+    case 'v':
+      sprintf(device, "%s", optarg_);
+      break;
+    case 'x':
+      verbose = true;
+      break;
+    case 'h':
+      usage(argv[0], NULL, fps, input, scale, niter, device, pixelformat, image_type, opath);
+      return false;
+      break;
 
     default:
-      usage(argv[0], optarg_, fps, input, scale, niter,
-            device, pixelformat, image_type, opath); return false; break;
+      usage(argv[0], optarg_, fps, input, scale, niter, device, pixelformat, image_type, opath);
+      return false;
+      break;
     }
   }
 
   if ((c == 1) || (c == -1)) {
     // standalone param or error
-    usage(argv[0], NULL, fps, input, scale, niter, 
-          device, pixelformat, image_type, opath);
+    usage(argv[0], NULL, fps, input, scale, niter, device, pixelformat, image_type, opath);
     std::cerr << "ERROR: " << std::endl;
     std::cerr << "  Bad argument " << optarg_ << std::endl << std::endl;
     return false;
@@ -228,8 +244,7 @@ bool getOptions(int argc, const char **argv, unsigned &fps, unsigned &input,
   device.  Only grabbing of grey level images is possible in this
   example. Display these images using X11 or GTK.
 */
-int
-main(int argc, const char ** argv)
+int main(int argc, const char **argv)
 {
   try {
     unsigned int opt_fps = 25;
@@ -248,18 +263,17 @@ main(int argc, const char ** argv)
     vpImage_type opt_image_type = color_image;
 
     // Read the command line options
-    if (getOptions(argc, argv, opt_fps, opt_input, opt_scale, opt_display,
-                   opt_verbose, opt_iter, opt_device,
+    if (getOptions(argc, argv, opt_fps, opt_input, opt_scale, opt_display, opt_verbose, opt_iter, opt_device,
                    opt_pixelformat, opt_image_type, opt_save, opt_opath) == false) {
-      exit (-1);
+      exit(-1);
     }
 
     // Declare an image, this is a gray level image (unsigned char) and
     // an other one that is a color image. There size is not defined
     // yet. It will be defined when the image will acquired the first
     // time.
-    vpImage<unsigned char> Ig ; // grey level image
-    vpImage<vpRGBa> Ic ; // color image
+    vpImage<unsigned char> Ig; // grey level image
+    vpImage<vpRGBa> Ic;        // color image
 
     // Creates the grabber
     vpV4l2Grabber g;
@@ -276,24 +290,20 @@ main(int argc, const char ** argv)
       g.setFramerate(vpV4l2Grabber::framerate_50fps);
     if (opt_image_type == grey_image) {
       // Open the framegrabber with the specified settings on grey images
-      g.open(Ig) ;
+      g.open(Ig);
       // Acquire an image
-      g.acquire(Ig) ;
-      std::cout << "Grey image size: width : " << Ig.getWidth() <<  " height: "
-                << Ig.getHeight() << std::endl;
-    }
-    else {
+      g.acquire(Ig);
+      std::cout << "Grey image size: width : " << Ig.getWidth() << " height: " << Ig.getHeight() << std::endl;
+    } else {
       // Open the framegrabber with the specified settings on color images
-      g.open(Ic) ;
+      g.open(Ic);
       // Acquire an image
-      g.acquire(Ic) ;
-      std::cout << "Color image size: width : " << Ic.getWidth() <<  " height: "
-                << Ic.getHeight() << std::endl;
+      g.acquire(Ic);
+      std::cout << "Color image size: width : " << Ic.getWidth() << " height: " << Ic.getHeight() << std::endl;
     }
 
-
-    // We open a window using either X11 or GTK.
-    // Its size is automatically defined by the image (I) size
+// We open a window using either X11 or GTK.
+// Its size is automatically defined by the image (I) size
 #if defined VISP_HAVE_X11
     vpDisplayX display;
 #elif defined VISP_HAVE_GTK
@@ -307,39 +317,36 @@ main(int argc, const char ** argv)
       // therefore is is no longuer necessary to make a reference to the
       // display variable.
       if (opt_image_type == grey_image) {
-        display.init(Ig, 100, 100, "V4L2 grey images framegrabbing") ;
-        vpDisplay::display(Ig) ;
-        vpDisplay::flush(Ig) ;
-      }
-      else {
-        display.init(Ic, 100, 100, "V4L2 color images framegrabbing") ;
-        vpDisplay::display(Ic) ;
-        vpDisplay::flush(Ic) ;
+        display.init(Ig, 100, 100, "V4L2 grey images framegrabbing");
+        vpDisplay::display(Ig);
+        vpDisplay::flush(Ig);
+      } else {
+        display.init(Ic, 100, 100, "V4L2 color images framegrabbing");
+        vpDisplay::display(Ic);
+        vpDisplay::flush(Ic);
       }
     }
     // Acquisition loop
     long cpt = 1;
-    while(cpt ++ < opt_iter)
-    {
+    while (cpt++ < opt_iter) {
       // Measure the initial time of an iteration
       double t = vpTime::measureTimeMs();
       // Acquire the image
       if (opt_image_type == grey_image) {
-        g.acquire(Ig) ;
+        g.acquire(Ig);
         if (opt_display) {
           // Display the image
-          vpDisplay::display(Ig) ;
+          vpDisplay::display(Ig);
           // Flush the display
-          vpDisplay::flush(Ig) ;
+          vpDisplay::flush(Ig);
         }
-      }
-      else {
-        g.acquire(Ic) ;
+      } else {
+        g.acquire(Ic);
         if (opt_display) {
           // Display the image
-          vpDisplay::display(Ic) ;
+          vpDisplay::display(Ic);
           // Flush the display
-          vpDisplay::flush(Ic) ;
+          vpDisplay::flush(Ic);
         }
       }
 
@@ -350,8 +357,7 @@ main(int argc, const char ** argv)
         std::cout << "Write: " << filename << std::endl;
         if (opt_image_type == grey_image) {
           vpImageIo::write(Ig, filename);
-        }
-        else {
+        } else {
           vpImageIo::write(Ic, filename);
         }
       }
@@ -362,24 +368,14 @@ main(int argc, const char ** argv)
 
     g.close();
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return 1;
   }
 }
 #else
-int
-main()
-{
-  vpTRACE("X11 or GTK display are not available") ;
-}
+int main() { vpTRACE("X11 or GTK display are not available"); }
 #endif
 #else
-int
-main()
-{
-  vpTRACE("Video 4 Linux 2 frame grabber drivers are not available") ;
-}
+int main() { vpTRACE("Video 4 Linux 2 frame grabber drivers are not available"); }
 #endif
-
