@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -49,30 +50,31 @@
 #include <visp3/core/vpConfig.h>
 #include <visp3/core/vpDebug.h>
 
-#if ((defined (VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI)) && (VISP_HAVE_OPENCV_VERSION >= 0x020000) && (VISP_HAVE_OPENCV_VERSION < 0x030000))
+#if ((defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI)) &&                                   \
+     (VISP_HAVE_OPENCV_VERSION >= 0x020000) && (VISP_HAVE_OPENCV_VERSION < 0x030000))
 
+#include <iomanip>
 #include <iostream>
 #include <stdlib.h>
-#include <visp3/vision/vpPlanarObjectDetector.h>
-#include <visp3/io/vpParseArgv.h>
 #include <visp3/core/vpConfig.h>
 #include <visp3/core/vpImage.h>
-#include <visp3/gui/vpDisplayX.h>
-#include <visp3/gui/vpDisplayGTK.h>
-#include <visp3/gui/vpDisplayGDI.h>
-#include <visp3/vision/vpHomography.h>
-#include <visp3/io/vpImageIo.h>
 #include <visp3/core/vpIoTools.h>
 #include <visp3/core/vpTime.h>
-#include <iomanip>
-#include <visp3/sensor/vpV4l2Grabber.h>
+#include <visp3/gui/vpDisplayGDI.h>
+#include <visp3/gui/vpDisplayGTK.h>
+#include <visp3/gui/vpDisplayX.h>
+#include <visp3/io/vpImageIo.h>
+#include <visp3/io/vpParseArgv.h>
 #include <visp3/sensor/vp1394TwoGrabber.h>
+#include <visp3/sensor/vpV4l2Grabber.h>
+#include <visp3/vision/vpHomography.h>
+#include <visp3/vision/vpPlanarObjectDetector.h>
 
-#define GETOPTARGS  "hlcdb:i:p"
+#define GETOPTARGS "hlcdb:i:p"
 
 void usage(const char *name, const char *badparam);
-bool getOptions(int argc, const char **argv, bool &isLearning, std::string& dataFile, bool& click_allowed,
-                bool& display, bool& displayPoints, std::string& ipath);
+bool getOptions(int argc, const char **argv, bool &isLearning, std::string &dataFile, bool &click_allowed,
+                bool &display, bool &displayPoints, std::string &ipath);
 
 /*!
 
@@ -99,7 +101,7 @@ OPTIONS:                                               \n\
 \n\
   -i <input image path>                                \n\
      Set image input path.\n\
-     From this path read \"ViSP-images/line/image.%%04d.pgm\"\n\
+     From this path read \"line/image.%%04d.pgm\"\n\
      images. \n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
      variable produces the same behaviour than using\n\
@@ -126,7 +128,6 @@ OPTIONS:                                               \n\
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
-
 }
 
 /*!
@@ -145,24 +146,40 @@ OPTIONS:                                               \n\
   \return false if the program has to be stopped, true otherwise.
 
 */
-bool getOptions(int argc, const char **argv, bool &isLearning, std::string& dataFile, bool& click_allowed,
-                bool& display, bool& displayPoints, std::string& ipath)
+bool getOptions(int argc, const char **argv, bool &isLearning, std::string &dataFile, bool &click_allowed,
+                bool &display, bool &displayPoints, std::string &ipath)
 {
   const char *optarg_;
-  int   c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg_)) > 1) {
 
     switch (c) {
-    case 'c': click_allowed = false; break;
-    case 'd': display = false; break;
-    case 'l': isLearning = true; break;
-    case 'h': usage(argv[0], NULL); return false; break;
-    case 'b': dataFile = optarg_; break;
-    case 'p': displayPoints = true; break;
-    case 'i': ipath = optarg_; break;
+    case 'c':
+      click_allowed = false;
+      break;
+    case 'd':
+      display = false;
+      break;
+    case 'l':
+      isLearning = true;
+      break;
+    case 'h':
+      usage(argv[0], NULL);
+      return false;
+      break;
+    case 'b':
+      dataFile = optarg_;
+      break;
+    case 'p':
+      displayPoints = true;
+      break;
+    case 'i':
+      ipath = optarg_;
+      break;
     default:
       usage(argv[0], optarg_);
-      return false; break;
+      return false;
+      break;
     }
   }
 
@@ -177,10 +194,7 @@ bool getOptions(int argc, const char **argv, bool &isLearning, std::string& data
   return true;
 }
 
-
-
-int 
-main(int argc, const char** argv)
+int main(int argc, const char **argv)
 {
   try {
     bool isLearning = false;
@@ -195,22 +209,23 @@ main(int argc, const char** argv)
     std::string dirname;
     std::string filename;
 
-    // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH environment variable value
+    // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH
+    // environment variable value
     env_ipath = vpIoTools::getViSPImagesDataPath();
 
     // Set the default input path
-    if (! env_ipath.empty()){
+    if (!env_ipath.empty()) {
       ipath = env_ipath;
     }
 
     // Read the command line options
-    if (getOptions(argc, argv,
-                   isLearning, dataFile, opt_click_allowed, opt_display, displayPoints, opt_ipath) == false) {
-      exit (-1);
+    if (getOptions(argc, argv, isLearning, dataFile, opt_click_allowed, opt_display, displayPoints, opt_ipath) ==
+        false) {
+      exit(-1);
     }
 
     // Get the option values
-    if (!opt_ipath.empty()){
+    if (!opt_ipath.empty()) {
       ipath = opt_ipath;
     }
 
@@ -218,8 +233,7 @@ main(int argc, const char** argv)
     // the input path comming from the command line option
     if (!opt_ipath.empty() && !env_ipath.empty()) {
       if (ipath != env_ipath) {
-        std::cout << std::endl
-                  << "WARNING: " << std::endl;
+        std::cout << std::endl << "WARNING: " << std::endl;
         std::cout << "  Since -i <visp image path=" << ipath << "> "
                   << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
                   << "  we skip the environment variable." << std::endl;
@@ -227,23 +241,22 @@ main(int argc, const char** argv)
     }
 
     // Test if an input path is set
-    if (opt_ipath.empty() && env_ipath.empty()){
+    if (opt_ipath.empty() && env_ipath.empty()) {
       usage(argv[0], NULL);
-      std::cerr << std::endl
-                << "ERROR:" << std::endl;
-      std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH "
-                << std::endl
+      std::cerr << std::endl << "ERROR:" << std::endl;
+      std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
                 << "  environment variable to specify the location of the " << std::endl
-                << "  image path where test images are located." << std::endl << std::endl;
+                << "  image path where test images are located." << std::endl
+                << std::endl;
       exit(-1);
     }
 
     // Declare two images, these are gray level images (unsigned char)
-    vpImage <unsigned char> I;
-    vpImage <unsigned char> Iref;
+    vpImage<unsigned char> I;
+    vpImage<unsigned char> Iref;
 
     // Set the path location of the image sequence
-    dirname = vpIoTools::createFilePath(ipath, "ViSP-images/cube");
+    dirname = vpIoTools::createFilePath(ipath, "cube");
 
     // Build the name of the image file
     unsigned iter = 0; // Image number
@@ -258,23 +271,19 @@ main(int argc, const char** argv)
     //
     // exception readPGM may throw various exception if, for example,
     // the file does not exist, or if the memory cannot be allocated
-    try{
+    try {
       std::cout << "Load: " << filename << std::endl;
-      vpImageIo::read(Iref, filename) ;
+      vpImageIo::read(Iref, filename);
       I = Iref;
-    }
-    catch(...)
-    {
-      // an exception is throwned if an exception from readPGM has been catched
-      // here this will result in the end of the program
-      // Note that another error message has been printed from readPGM
-      // to give more information about the error
-      std::cerr << std::endl
-                << "ERROR:" << std::endl;
+    } catch (...) {
+      // an exception is throwned if an exception from readPGM has been
+      // catched here this will result in the end of the program Note that
+      // another error message has been printed from readPGM to give more
+      // information about the error
+      std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Cannot read " << filename << std::endl;
       std::cerr << "  Check your -i " << ipath << " option " << std::endl
-                << "  or VISP_INPUT_IMAGE_PATH environment variable."
-                << std::endl;
+                << "  or VISP_INPUT_IMAGE_PATH environment variable." << std::endl;
       exit(-1);
     }
 
@@ -298,82 +307,85 @@ main(int argc, const char** argv)
     vpPlanarObjectDetector planar;
 
     vpImagePoint corners[2];
-    if(isLearning){
-      if(opt_display){
-        displayRef.init(Iref, 100, 100, "Reference image") ;
+    if (isLearning) {
+      if (opt_display) {
+        displayRef.init(Iref, 100, 100, "Reference image");
         vpDisplay::display(Iref);
         vpDisplay::flush(Iref);
       }
-      if (opt_display && opt_click_allowed){
-        std::cout << "Click on the top left and the bottom right corners to define the reference plane" << std::endl;
-        for (int i=0 ; i < 2 ; i++){
+      if (opt_display && opt_click_allowed) {
+        std::cout << "Click on the top left and the bottom right corners to "
+                     "define the reference plane"
+                  << std::endl;
+        for (int i = 0; i < 2; i++) {
           vpDisplay::getClick(Iref, corners[i]);
           std::cout << corners[i] << std::endl;
         }
-      }
-      else{
-        corners[0].set_ij(50, I.getWidth()-100);// small ROI for the automated test
-        corners[1].set_ij(I.getHeight()-100, I.getWidth()-2);
+      } else {
+        corners[0].set_ij(50, I.getWidth() - 100); // small ROI for the automated test
+        corners[1].set_ij(I.getHeight() - 100, I.getWidth() - 2);
       }
 
       if (opt_display) {
-        //Display the rectangle which defines the part of the image where the reference points are computed.
+        // Display the rectangle which defines the part of the image where the
+        // reference points are computed.
         vpDisplay::displayRectangle(Iref, corners[0], corners[1], vpColor::green);
         vpDisplay::flush(Iref);
       }
 
-      if (opt_click_allowed){
+      if (opt_click_allowed) {
         std::cout << "Click on the image to continue" << std::endl;
         vpDisplay::getClick(Iref);
       }
 
       vpRect roi(corners[0], corners[1]);
 
-      std::cout << "> train the classifier on the selected plane (may take up to several minutes)." << std::endl;
-      if(opt_display) {
+      std::cout << "> train the classifier on the selected plane (may take "
+                   "up to several minutes)."
+                << std::endl;
+      if (opt_display) {
         vpDisplay::display(Iref);
         vpDisplay::flush(Iref);
       }
-      double t0 = vpTime::measureTimeMs ();
+      double t0 = vpTime::measureTimeMs();
       planar.buildReference(Iref, roi);
-      std::cout << "build reference in " << vpTime::measureTimeMs () - t0 << " ms" << std::endl;
-      t0 = vpTime::measureTimeMs ();
+      std::cout << "build reference in " << vpTime::measureTimeMs() - t0 << " ms" << std::endl;
+      t0 = vpTime::measureTimeMs();
       planar.recordDetector(objectName, dataFile);
-      std::cout << "record detector in " << vpTime::measureTimeMs () - t0 << " ms" << std::endl;
-    }
-    else{
-      if(!vpIoTools::checkFilename(dataFile)){
-        vpERROR_TRACE("cannot load the database with the specified name. Has the object been learned with the -l option? ");
+      std::cout << "record detector in " << vpTime::measureTimeMs() - t0 << " ms" << std::endl;
+    } else {
+      if (!vpIoTools::checkFilename(dataFile)) {
+        vpERROR_TRACE("cannot load the database with the specified name. Has "
+                      "the object been learned with the -l option? ");
         exit(-1);
       }
-      try{
+      try {
         // load a previously recorded file
         planar.load(dataFile, objectName);
-      }
-      catch(...){
-        vpERROR_TRACE("cannot load the database with the specified name. Has the object been learned with the -l option? ");
+      } catch (...) {
+        vpERROR_TRACE("cannot load the database with the specified name. Has "
+                      "the object been learned with the -l option? ");
         exit(-1);
       }
     }
 
-    if(opt_display){
-      display.init(I, 110 + (int)Iref.getWidth(), 100, "Current image") ;
+    if (opt_display) {
+      display.init(I, 110 + (int)Iref.getWidth(), 100, "Current image");
       vpDisplay::display(I);
       vpDisplay::flush(I);
     }
 
-    if (opt_display && opt_click_allowed){
+    if (opt_display && opt_click_allowed) {
       std::cout << "Click on the reference image to continue" << std::endl;
-      vpDisplay::displayText(Iref, vpImagePoint(15,15),
-                             "Click on the reference image to continue", vpColor::red);
+      vpDisplay::displayText(Iref, vpImagePoint(15, 15), "Click on the reference image to continue", vpColor::red);
       vpDisplay::flush(Iref);
       vpDisplay::getClick(Iref);
     }
 
-    for ( ; ; ) {
+    for (;;) {
       // acquire a new image
       iter++;
-      if(iter >= 80){
+      if (iter >= 80) {
         break;
       }
       s.str("");
@@ -382,54 +394,51 @@ main(int argc, const char** argv)
       // read the image
       vpImageIo::read(I, filename);
 
-      if(opt_display){
+      if (opt_display) {
         vpDisplay::display(I);
       }
 
-      double t0 = vpTime::measureTimeMs ();
+      double t0 = vpTime::measureTimeMs();
       // detection  of the reference planar surface
       bool isDetected = planar.matchPoint(I);
-      std::cout << "matching in " << vpTime::measureTimeMs () - t0 << " ms" << std::endl;
+      std::cout << "matching in " << vpTime::measureTimeMs() - t0 << " ms" << std::endl;
 
-      if(isDetected){
+      if (isDetected) {
         vpHomography H;
         planar.getHomography(H);
         std::cout << " > computed homography:" << std::endl << H << std::endl;
-        if(opt_display){
-          if(isLearning){
+        if (opt_display) {
+          if (isLearning) {
             vpDisplay::display(Iref);
             vpDisplay::displayRectangle(Iref, corners[0], corners[1], vpColor::green);
             planar.display(Iref, I, displayPoints);
             vpDisplay::flush(Iref);
-          }else{
+          } else {
             planar.display(I, displayPoints);
           }
         }
-      }
-      else{
+      } else {
         std::cout << " > reference is not detected in the image" << std::endl;
       }
-      if(opt_display){
+      if (opt_display) {
         vpDisplay::flush(I);
-        if(vpDisplay::getClick(I, false)){
+        if (vpDisplay::getClick(I, false)) {
           break;
         }
       }
     }
 
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return 1;
   }
 }
 
 #else
-int
-main()
+int main()
 {
-#if ( ! (defined (VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI)) ) 
+#if (!(defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI)))
   vpERROR_TRACE("You do not have X11, GTK or GDI display functionalities...");
 #else
   vpERROR_TRACE("You do not have OpenCV-2.0.0 or a more recent release...");
