@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -41,23 +42,20 @@
   \brief Parsing command line arguments.
 */
 
-
 /*!
   \example parse-argv1.cpp
 
   Example of command line parsing.
 */
 
-
-
+#include <iomanip>
+#include <sstream>
+#include <stdio.h>
+#include <stdlib.h>
 #include <visp3/core/vpDebug.h>
 #include <visp3/io/vpParseArgv.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <sstream>
-#include <iomanip>
 // List of allowed command line options
-#define GETOPTARGS	"d:f:i:h"
+#define GETOPTARGS "d:f:i:h"
 
 void usage(const char *name, const char *badparam, int i_val, float f_val, double d_val);
 bool getOptions(int argc, const char **argv, int &i_val, float &f_val, double &d_val);
@@ -94,11 +92,10 @@ OPTIONS:                                               Default\n\
      A double value.\n\
 \n\
   -h\n\
-     Print the help.\n\n",
-	  i_val, f_val, d_val);
+     Print the help.\n\n", i_val, f_val, d_val);
 
   if (badparam) {
-    fprintf(stderr, "ERROR: \n" );
+    fprintf(stderr, "ERROR: \n");
     fprintf(stderr, "\nBad parameter [%s]\n", badparam);
   }
 }
@@ -118,17 +115,28 @@ OPTIONS:                                               Default\n\
 bool getOptions(int argc, const char **argv, int &i_val, float &f_val, double &d_val)
 {
   const char *optarg_;
-  int	c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg_)) > 1) {
 
     switch (c) {
-    case 'd': d_val = atof(optarg_); break;
-    case 'f': f_val = (float) atof(optarg_); break;
-    case 'i': i_val = atoi(optarg_); break;
-    case 'h': usage(argv[0], NULL, i_val, f_val, d_val); return false; break;
+    case 'd':
+      d_val = atof(optarg_);
+      break;
+    case 'f':
+      f_val = (float)atof(optarg_);
+      break;
+    case 'i':
+      i_val = atoi(optarg_);
+      break;
+    case 'h':
+      usage(argv[0], NULL, i_val, f_val, d_val);
+      return false;
+      break;
 
     default:
-      usage(argv[0], optarg_, i_val, f_val, d_val); return false; break;
+      usage(argv[0], optarg_, i_val, f_val, d_val);
+      return false;
+      break;
     }
   }
 
@@ -143,15 +151,14 @@ bool getOptions(int argc, const char **argv, int &i_val, float &f_val, double &d
   return true;
 }
 
-int
-main(int argc, const char ** argv)
+int main(int argc, const char **argv)
 {
   try {
     using ::std::cout;
     using ::std::endl;
 
-    int    i_val = 3;
-    float  f_val = 3.14f;
+    int i_val = 3;
+    float f_val = 3.14f;
     double d_val = 3.1415;
 
     // Read the command line options
@@ -163,12 +170,10 @@ main(int argc, const char ** argv)
     cout << "  Integer value: " << i_val << endl;
     cout << "  Float   value: " << f_val << endl;
     cout << "  Double  value: " << d_val << endl << endl;
-    cout << "Call  " << argv[0]
-         << " -h to see how to change these parameters." << endl;
+    cout << "Call  " << argv[0] << " -h to see how to change these parameters." << endl;
 
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
     return 1;
   }
