@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -46,32 +47,32 @@
   - display the camera view.
 */
 
-#include <visp3/core/vpDebug.h>
 #include <visp3/core/vpConfig.h>
+#include <visp3/core/vpDebug.h>
 
-#if (defined (VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
+#if (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
 
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 
 #include <visp3/core/vpCameraParameters.h>
 #include <visp3/core/vpCircle.h>
-#include <visp3/gui/vpDisplayX.h>
-#include <visp3/gui/vpDisplayGTK.h>
-#include <visp3/gui/vpDisplayGDI.h>
-#include <visp3/gui/vpDisplayOpenCV.h>
-#include <visp3/visual_features/vpFeatureBuilder.h>
-#include <visp3/visual_features/vpFeatureLine.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
 #include <visp3/core/vpImage.h>
 #include <visp3/core/vpMath.h>
+#include <visp3/gui/vpDisplayGDI.h>
+#include <visp3/gui/vpDisplayGTK.h>
+#include <visp3/gui/vpDisplayOpenCV.h>
+#include <visp3/gui/vpDisplayX.h>
 #include <visp3/io/vpParseArgv.h>
-#include <visp3/vs/vpServo.h>
 #include <visp3/robot/vpSimulatorCamera.h>
+#include <visp3/visual_features/vpFeatureBuilder.h>
+#include <visp3/visual_features/vpFeatureLine.h>
+#include <visp3/vs/vpServo.h>
 #include <visp3/vs/vpServoDisplay.h>
 
 // List of allowed command line options
-#define GETOPTARGS	"cdh"
+#define GETOPTARGS "cdh"
 
 void usage(const char *name, const char *badparam);
 bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display);
@@ -109,7 +110,7 @@ OPTIONS:                                               Default\n\
      Print the help.\n");
 
   if (badparam) {
-    fprintf(stderr, "ERROR: \n" );
+    fprintf(stderr, "ERROR: \n");
     fprintf(stderr, "\nBad parameter [%s]\n", badparam);
   }
 }
@@ -129,17 +130,25 @@ Set the program options.
 bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display)
 {
   const char *optarg_;
-  int	c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg_)) > 1) {
 
     switch (c) {
-    case 'c': click_allowed = false; break;
-    case 'd': display = false; break;
-    case 'h': usage(argv[0], NULL); return false; break;
+    case 'c':
+      click_allowed = false;
+      break;
+    case 'd':
+      display = false;
+      break;
+    case 'h':
+      usage(argv[0], NULL);
+      return false;
+      break;
 
     default:
       usage(argv[0], optarg_);
-      return false; break;
+      return false;
+      break;
     }
   }
 
@@ -154,9 +163,7 @@ bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display)
   return true;
 }
 
-
-int
-main(int argc, const char ** argv)
+int main(int argc, const char **argv)
 {
   try {
     bool opt_display = true;
@@ -164,12 +171,12 @@ main(int argc, const char ** argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_click_allowed, opt_display) == false) {
-      exit (-1);
+      exit(-1);
     }
 
-    vpImage<unsigned char> I(512,512,0) ;
+    vpImage<unsigned char> I(512, 512, 0);
 
-    // We open a window using either X11, GTK or GDI.
+// We open a window using either X11, GTK or GDI.
 #if defined VISP_HAVE_X11
     vpDisplayX display;
 #elif defined VISP_HAVE_GTK
@@ -181,126 +188,116 @@ main(int argc, const char ** argv)
 #endif
 
     if (opt_display) {
-      try{
+      try {
         // Display size is automatically defined by the image (I) size
-        display.init(I, 100, 100,"Camera view...") ;
+        display.init(I, 100, 100, "Camera view...");
         // Display the image
         // The image class has a member that specify a pointer toward
         // the display that has been initialized in the display declaration
         // therefore is is no longuer necessary to make a reference to the
         // display variable.
-        vpDisplay::display(I) ;
-        vpDisplay::flush(I) ;
-      }
-      catch(...)
-      {
-        vpERROR_TRACE("Error while displaying the image") ;
+        vpDisplay::display(I);
+        vpDisplay::flush(I);
+      } catch (...) {
+        vpERROR_TRACE("Error while displaying the image");
         exit(-1);
       }
     }
 
-    double px, py ; px = py = 600 ;
-    double u0, v0 ; u0 = v0 = 256 ;
+    double px, py;
+    px = py = 600;
+    double u0, v0;
+    u0 = v0 = 256;
 
-    vpCameraParameters cam(px,py,u0,v0);
+    vpCameraParameters cam(px, py, u0, v0);
 
-    vpServo task ;
-    vpSimulatorCamera robot ;
+    vpServo task;
+    vpSimulatorCamera robot;
 
     // sets the initial camera location
-    vpHomogeneousMatrix cMo(0,0,1,
-                            vpMath::rad(0),  vpMath::rad(80),  vpMath::rad(30))   ;
+    vpHomogeneousMatrix cMo(0, 0, 1, vpMath::rad(0), vpMath::rad(80), vpMath::rad(30));
     vpHomogeneousMatrix wMc, wMo;
-    robot.getPosition(wMc) ;
+    robot.getPosition(wMc);
     wMo = wMc * cMo; // Compute the position of the object in the world frame
 
-    vpHomogeneousMatrix cMod(-0.1,-0.1,0.7,
-                             vpMath::rad(40),  vpMath::rad(10),  vpMath::rad(30))   ;
+    vpHomogeneousMatrix cMod(-0.1, -0.1, 0.7, vpMath::rad(40), vpMath::rad(10), vpMath::rad(30));
 
     // sets the circle coordinates in the world frame
-    vpCircle circle ;
-    circle.setWorldCoordinates(0,0,1,
-                               0,0,0,
-                               0.1) ;
+    vpCircle circle;
+    circle.setWorldCoordinates(0, 0, 1, 0, 0, 0, 0.1);
 
     // sets the desired position of the visual feature
-    vpFeatureEllipse pd ;
-    circle.track(cMod) ;
-    vpFeatureBuilder::create(pd,circle)  ;
+    vpFeatureEllipse pd;
+    circle.track(cMod);
+    vpFeatureBuilder::create(pd, circle);
 
-    // project : computes the circle coordinates in the camera frame and its 2D coordinates
-    // sets the current position of the visual feature
-    vpFeatureEllipse p ;
-    circle.track(cMo) ;
-    vpFeatureBuilder::create(p,circle)  ;
+    // project : computes the circle coordinates in the camera frame and its
+    // 2D coordinates sets the current position of the visual feature
+    vpFeatureEllipse p;
+    circle.track(cMo);
+    vpFeatureBuilder::create(p, circle);
 
     // define the task
     // - we want an eye-in-hand control law
     // - robot is controlled in the camera frame
-    task.setServo(vpServo::EYEINHAND_CAMERA) ;
-    task.setInteractionMatrixType(vpServo::DESIRED) ;
+    task.setServo(vpServo::EYEINHAND_CAMERA);
+    task.setInteractionMatrixType(vpServo::DESIRED);
     // - we want to see a circle on a circle
-    task.addFeature(p,pd) ;
+    task.addFeature(p, pd);
     // - set the gain
-    task.setLambda(1) ;
+    task.setLambda(1);
 
     // Display task information
-    task.print() ;
+    task.print();
 
-    unsigned int iter=0 ;
+    unsigned int iter = 0;
     // loop
-    while(iter++ < 200)
-    {
-      std::cout << "---------------------------------------------" << iter <<std::endl ;
-      vpColVector v ;
+    while (iter++ < 200) {
+      std::cout << "---------------------------------------------" << iter << std::endl;
+      vpColVector v;
 
       // get the robot position
-      robot.getPosition(wMc) ;
+      robot.getPosition(wMc);
       // Compute the position of the camera wrt the object frame
       cMo = wMc.inverse() * wMo;
 
       // new circle position
       // retrieve x,y and Z of the vpCircle structure
-      circle.track(cMo) ;
-      vpFeatureBuilder::create(p,circle);
-      circle.print() ;
-      p.print() ;
+      circle.track(cMo);
+      vpFeatureBuilder::create(p, circle);
+      circle.print();
+      p.print();
 
       if (opt_display) {
-        vpDisplay::display(I) ;
-        vpServoDisplay::display(task,cam,I) ;
-        vpDisplay::flush(I) ;
+        vpDisplay::display(I);
+        vpServoDisplay::display(task, cam, I);
+        vpDisplay::flush(I);
       }
 
       // compute the control law
-      v = task.computeControlLaw() ;
-      std::cout << "task rank: " << task.getTaskRank() <<std::endl ;
+      v = task.computeControlLaw();
+      std::cout << "task rank: " << task.getTaskRank() << std::endl;
       // send the camera velocity to the controller
-      robot.setVelocity(vpRobot::CAMERA_FRAME, v) ;
+      robot.setVelocity(vpRobot::CAMERA_FRAME, v);
 
-      std::cout << "|| s - s* || = " << ( task.getError() ).sumSquare() <<std::endl ;
+      std::cout << "|| s - s* || = " << (task.getError()).sumSquare() << std::endl;
     }
 
     // Display task information
-    task.print() ;
+    task.print();
     task.kill();
 
     if (opt_display && opt_click_allowed) {
       std::cout << "Click in the camera view window to end..." << std::endl;
-      vpDisplay::getClick(I) ;
+      vpDisplay::getClick(I);
     }
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
     return 1;
   }
 }
 #else
-int
-main()
-{
-  vpERROR_TRACE("You do not have X11, GTK, GDI or OpenCV display functionalities...");
-}
+int main() { vpERROR_TRACE("You do not have X11, GTK, GDI or OpenCV display functionalities..."); }
 
 #endif
