@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -36,7 +37,6 @@
  *
  *****************************************************************************/
 
-
 /*!
   \example servoSimuFourPoints2DPolarCamVelocityDisplay.cpp
 
@@ -53,35 +53,35 @@
 
 */
 
-#include <visp3/core/vpDebug.h>
 #include <visp3/core/vpConfig.h>
+#include <visp3/core/vpDebug.h>
 
-#if (defined (VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
+#if (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
 
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 
 #include <visp3/core/vpCameraParameters.h>
-#include <visp3/gui/vpDisplayX.h>
-#include <visp3/gui/vpDisplayGTK.h>
-#include <visp3/gui/vpDisplayGDI.h>
-#include <visp3/gui/vpDisplayOpenCV.h>
-#include <visp3/visual_features/vpFeatureBuilder.h>
-#include <visp3/visual_features/vpFeaturePointPolar.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
 #include <visp3/core/vpImage.h>
 #include <visp3/core/vpImagePoint.h>
 #include <visp3/core/vpIoTools.h>
 #include <visp3/core/vpMath.h>
 #include <visp3/core/vpMeterPixelConversion.h>
+#include <visp3/gui/vpDisplayGDI.h>
+#include <visp3/gui/vpDisplayGTK.h>
+#include <visp3/gui/vpDisplayOpenCV.h>
+#include <visp3/gui/vpDisplayX.h>
 #include <visp3/gui/vpProjectionDisplay.h>
+#include <visp3/io/vpParseArgv.h>
+#include <visp3/robot/vpSimulatorCamera.h>
+#include <visp3/visual_features/vpFeatureBuilder.h>
+#include <visp3/visual_features/vpFeaturePointPolar.h>
 #include <visp3/vs/vpServo.h>
 #include <visp3/vs/vpServoDisplay.h>
-#include <visp3/robot/vpSimulatorCamera.h>
-#include <visp3/io/vpParseArgv.h>
 
 // List of allowed command line options
-#define GETOPTARGS	"cdh"
+#define GETOPTARGS "cdh"
 
 void usage(const char *name, const char *badparam);
 bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display);
@@ -136,17 +136,25 @@ Set the program options.
 bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display)
 {
   const char *optarg_;
-  int	c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg_)) > 1) {
 
     switch (c) {
-    case 'c': click_allowed = false; break;
-    case 'd': display = false; break;
-    case 'h': usage(argv[0], NULL); return false; break;
+    case 'c':
+      click_allowed = false;
+      break;
+    case 'd':
+      display = false;
+      break;
+    case 'h':
+      usage(argv[0], NULL);
+      return false;
+      break;
 
     default:
       usage(argv[0], optarg_);
-      return false; break;
+      return false;
+      break;
     }
   }
 
@@ -161,8 +169,7 @@ bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display)
   return true;
 }
 
-int
-main(int argc, const char ** argv)
+int main(int argc, const char **argv)
 {
   try {
     // Log file creation in /tmp/$USERNAME/log.dat
@@ -178,9 +185,9 @@ main(int argc, const char ** argv)
     // Create a log filename to save velocities...
     std::string logdirname;
 #if defined(_WIN32)
-    logdirname ="C:/temp/" + username;
+    logdirname = "C:/temp/" + username;
 #else
-    logdirname ="/tmp/" + username;
+    logdirname = "/tmp/" + username;
 #endif
 
     // Test if the output path exist. If no try to create it
@@ -188,10 +195,8 @@ main(int argc, const char ** argv)
       try {
         // Create the dirname
         vpIoTools::makeDirectory(logdirname);
-      }
-      catch (...) {
-        std::cerr << std::endl
-                  << "ERROR:" << std::endl;
+      } catch (...) {
+        std::cerr << std::endl << "ERROR:" << std::endl;
         std::cerr << "  Cannot create " << logdirname << std::endl;
         exit(-1);
       }
@@ -202,17 +207,16 @@ main(int argc, const char ** argv)
     // Open the log file name
     std::ofstream flog(logfilename.c_str());
 
-
     bool opt_click_allowed = true;
     bool opt_display = true;
 
     // Read the command line options
     if (getOptions(argc, argv, opt_click_allowed, opt_display) == false) {
-      exit (-1);
+      exit(-1);
     }
 
-    // We open two displays, one for the internal camera view, the other one for
-    // the external view, using either X11, GTK or GDI.
+// We open two displays, one for the internal camera view, the other one for
+// the external view, using either X11, GTK or GDI.
 #if defined VISP_HAVE_X11
     vpDisplayX displayInt;
     vpDisplayX displayExt;
@@ -229,132 +233,116 @@ main(int argc, const char ** argv)
 
     // open a display for the visualization
 
-    vpImage<unsigned char> Iint(300, 300, 0) ;
-    vpImage<unsigned char> Iext(300, 300, 0) ;
+    vpImage<unsigned char> Iint(300, 300, 0);
+    vpImage<unsigned char> Iext(300, 300, 0);
 
     if (opt_display) {
-      displayInt.init(Iint,0,0, "Internal view") ;
-      displayExt.init(Iext,330,000, "External view") ;
-
+      displayInt.init(Iint, 0, 0, "Internal view");
+      displayExt.init(Iext, 330, 000, "External view");
     }
-    vpProjectionDisplay externalview ;
+    vpProjectionDisplay externalview;
 
-    double px, py ; px = py = 500 ;
-    double u0, v0 ; u0 = 150, v0 = 160 ;
+    double px, py;
+    px = py = 500;
+    double u0, v0;
+    u0 = 150, v0 = 160;
 
-    vpCameraParameters cam(px,py,u0,v0);
+    vpCameraParameters cam(px, py, u0, v0);
 
-    int i ;
-    vpServo task ;
-    vpSimulatorCamera robot ;
+    int i;
+    vpServo task;
+    vpSimulatorCamera robot;
 
+    std::cout << std::endl;
+    std::cout << "----------------------------------------------" << std::endl;
+    std::cout << " Test program for vpServo " << std::endl;
+    std::cout << " Eye-in-hand task control, articular velocity are computed" << std::endl;
+    std::cout << " Simulation " << std::endl;
+    std::cout << " task : servo 4 points " << std::endl;
+    std::cout << "----------------------------------------------" << std::endl;
+    std::cout << std::endl;
 
-    std::cout << std::endl ;
-    std::cout << "----------------------------------------------" << std::endl ;
-    std::cout << " Test program for vpServo "  <<std::endl ;
-    std::cout << " Eye-in-hand task control, articular velocity are computed"
-              << std::endl ;
-    std::cout << " Simulation " << std::endl ;
-    std::cout << " task : servo 4 points " << std::endl ;
-    std::cout << "----------------------------------------------" << std::endl ;
-    std::cout << std::endl ;
-
-    // #define TRANS_Z_PURE
-    // #define TRANS_X_PURE
-    // #define ROT_Z_PURE
-    // #define ROT_X_PURE
+// #define TRANS_Z_PURE
+// #define TRANS_X_PURE
+// #define ROT_Z_PURE
+// #define ROT_X_PURE
 #define COMPLEX
-    //#define PROBLEM
+//#define PROBLEM
 
 #if defined(TRANS_Z_PURE)
     // sets the initial camera location
-    vpHomogeneousMatrix cMo(0, 0, 3,
-                            vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cMo(0, 0, 3, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
     // sets the desired camera location
-    vpHomogeneousMatrix cMod(0, 0, 2,
-                             vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cMod(0, 0, 2, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
 #elif defined(TRANS_X_PURE)
     // sets the initial camera location
-    vpHomogeneousMatrix cMo(0.3, 0.3, 3,
-                            vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cMo(0.3, 0.3, 3, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
     // sets the desired camera location
-    vpHomogeneousMatrix cMod(0.5, 0.3, 3,
-                             vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cMod(0.5, 0.3, 3, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
 
 #elif defined(ROT_Z_PURE)
     // sets the initial camera location
-    vpHomogeneousMatrix cMo(0, 0, 3,
-                            vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cMo(0, 0, 3, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
     // sets the desired camera location
-    vpHomogeneousMatrix cMod(0, 0, 3,
-                             vpMath::rad(0), vpMath::rad(0), vpMath::rad(180));
+    vpHomogeneousMatrix cMod(0, 0, 3, vpMath::rad(0), vpMath::rad(0), vpMath::rad(180));
 
 #elif defined(ROT_X_PURE)
     // sets the initial camera location
-    vpHomogeneousMatrix cMo(0, 0, 3,
-                            vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cMo(0, 0, 3, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
     // sets the desired camera location
-    vpHomogeneousMatrix cMod(0, 0, 3,
-                             vpMath::rad(45), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cMod(0, 0, 3, vpMath::rad(45), vpMath::rad(0), vpMath::rad(0));
 
 #elif defined(COMPLEX)
     // sets the initial camera location
-    vpHomogeneousMatrix cMo(0.2, 0.2, 3,
-                            vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cMo(0.2, 0.2, 3, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
     // sets the desired camera location
-    vpHomogeneousMatrix cMod(0, 0, 2.5,
-                             vpMath::rad(45), vpMath::rad(10), vpMath::rad(30));
+    vpHomogeneousMatrix cMod(0, 0, 2.5, vpMath::rad(45), vpMath::rad(10), vpMath::rad(30));
 
 #elif defined(PROBLEM)
-    // Bad behavior with an interaction matrix computed from the desired features
-    // sets the initial camera location
-    vpHomogeneousMatrix cMo(0.2, 0.2, 3,
-                            vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    // Bad behavior with an interaction matrix computed from the desired
+    // features sets the initial camera location
+    vpHomogeneousMatrix cMo(0.2, 0.2, 3, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
     // sets the desired camera location
-    vpHomogeneousMatrix cMod(0.4, 0.2, 3,
-                             vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cMod(0.4, 0.2, 3, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
 
 #endif
     // Compute the position of the object in the world frame
     vpHomogeneousMatrix wMc, wMo;
-    robot.getPosition(wMc) ;
+    robot.getPosition(wMc);
     wMo = wMc * cMo;
 
-    vpHomogeneousMatrix cextMo(0,0,6,
-                               vpMath::rad(40),  vpMath::rad(10),  vpMath::rad(60))   ;
-
+    vpHomogeneousMatrix cextMo(0, 0, 6, vpMath::rad(40), vpMath::rad(10), vpMath::rad(60));
 
     // sets the point coordinates in the object frame
-    vpPoint point[4] ;
-    point[0].setWorldCoordinates(-0.25,-0.25,0) ;
-    point[1].setWorldCoordinates(0.25,-0.25,0) ;
-    point[2].setWorldCoordinates(0.25,0.25,0) ;
-    point[3].setWorldCoordinates(-0.25,0.25,0) ;
+    vpPoint point[4];
+    point[0].setWorldCoordinates(-0.25, -0.25, 0);
+    point[1].setWorldCoordinates(0.25, -0.25, 0);
+    point[2].setWorldCoordinates(0.25, 0.25, 0);
+    point[3].setWorldCoordinates(-0.25, 0.25, 0);
 
-    for (i = 0 ; i < 4 ; i++)
-      externalview.insert(point[i]) ;
+    for (i = 0; i < 4; i++)
+      externalview.insert(point[i]);
 
     // sets the desired position of the feature point s*"
-    vpFeaturePointPolar pd[4] ;
+    vpFeaturePointPolar pd[4];
 
     // computes the point coordinates in the desired camera frame and
     // its 2D coordinates
-    for (i = 0 ; i < 4 ; i++) {
+    for (i = 0; i < 4; i++) {
       point[i].track(cMod);
       // Computes the polar coordinates from the image point
       // cartesian coordinates
-      vpFeatureBuilder::create(pd[i],point[i]);
+      vpFeatureBuilder::create(pd[i], point[i]);
     }
 
-
     // computes the point coordinates in the camera frame and its 2D
     // coordinates
-    for (i = 0 ; i < 4 ; i++)
-      point[i].track(cMo) ;
+    for (i = 0; i < 4; i++)
+      point[i].track(cMo);
 
     // sets the desired position of the point
-    vpFeaturePointPolar p[4] ;
-    for (i = 0 ; i < 4 ; i++) {
+    vpFeaturePointPolar p[4];
+    for (i = 0; i < 4; i++) {
       // retrieve x,y and Z of the vpPoint structure to initialize the
       // visual feature
       vpFeatureBuilder::create(p[i], point[i]);
@@ -363,74 +351,70 @@ main(int argc, const char ** argv)
     // Define the task;
     // - we want an eye-in-hand control law
     // - articular velocity are computed
-    task.setServo(vpServo::EYEINHAND_L_cVe_eJe) ;
+    task.setServo(vpServo::EYEINHAND_L_cVe_eJe);
     //  task.setInteractionMatrixType(vpServo::MEAN) ;
     //  task.setInteractionMatrixType(vpServo::DESIRED) ;
-    task.setInteractionMatrixType(vpServo::CURRENT) ;
-
+    task.setInteractionMatrixType(vpServo::CURRENT);
 
     // Set the position of the camera in the end-effector frame
-    vpHomogeneousMatrix cMe ;
-    vpVelocityTwistMatrix cVe(cMe) ;
-    task.set_cVe(cVe) ;
+    vpHomogeneousMatrix cMe;
+    vpVelocityTwistMatrix cVe(cMe);
+    task.set_cVe(cVe);
 
     // Set the Jacobian (expressed in the end-effector frame)
-    vpMatrix eJe ;
-    robot.get_eJe(eJe) ;
-    task.set_eJe(eJe) ;
+    vpMatrix eJe;
+    robot.get_eJe(eJe);
+    task.set_eJe(eJe);
 
     // we want to see a point on a point
-    for (i = 0 ; i < 4 ; i++)
-      task.addFeature(p[i],pd[i]) ;
+    for (i = 0; i < 4; i++)
+      task.addFeature(p[i], pd[i]);
 
     // set the gain
-    task.setLambda(1) ;
-
+    task.setLambda(1);
 
     std::cout << "\nDisplay task information: " << std::endl;
-    task.print() ;
+    task.print();
 
-    unsigned int iter=0 ;
+    unsigned int iter = 0;
     // loop
-    while(iter++ < 200) {
-      std::cout << "---------------------------------------------"
-                << iter <<std::endl ;
-      vpColVector v ;
-
+    while (iter++ < 200) {
+      std::cout << "---------------------------------------------" << iter << std::endl;
+      vpColVector v;
 
       // Set the Jacobian (expressed in the end-effector frame)
       // Since q is modified eJe is modified
-      robot.get_eJe(eJe) ;
-      task.set_eJe(eJe) ;
+      robot.get_eJe(eJe);
+      task.set_eJe(eJe);
 
       // get the robot position
-      robot.getPosition(wMc) ;
+      robot.getPosition(wMc);
       // Compute the position of the camera wrt the object frame
       cMo = wMc.inverse() * wMo;
 
       // Compute new point position
-      for (i = 0 ; i < 4 ; i++) {
-        point[i].track(cMo) ;
+      for (i = 0; i < 4; i++) {
+        point[i].track(cMo);
         // retrieve x,y and Z of the vpPoint structure to compute the feature
-        vpFeatureBuilder::create(p[i],point[i])  ;
+        vpFeatureBuilder::create(p[i], point[i]);
       }
 
       if (opt_display) {
-        vpDisplay::display(Iint) ;
-        vpDisplay::display(Iext) ;
+        vpDisplay::display(Iint);
+        vpDisplay::display(Iext);
 
-        vpServoDisplay::display(task,cam,Iint) ;
-        externalview.display(Iext,cextMo, cMo, cam, vpColor::green);
+        vpServoDisplay::display(task, cam, Iint);
+        externalview.display(Iext, cextMo, cMo, cam, vpColor::green);
         vpDisplay::flush(Iint);
         vpDisplay::flush(Iext);
       }
 
       // Compute the control law
-      v = task.computeControlLaw() ;
+      v = task.computeControlLaw();
 
-      if (iter==1) {
+      if (iter == 1) {
         std::cout << "Display task information: " << std::endl;
-        task.print() ;
+        task.print();
       }
 
       task.print(vpServo::FEATURE_CURRENT);
@@ -441,72 +425,63 @@ main(int argc, const char ** argv)
       // Save velocities applied to the robot in the log file
       // v[0], v[1], v[2] correspond to camera translation velocities in m/s
       // v[3], v[4], v[5] correspond to camera rotation velocities in rad/s
-      flog << v[0] << " " << v[1] << " " << v[2] << " "
-                   << v[3] << " " << v[4] << " " << v[5] << " ";
+      flog << v[0] << " " << v[1] << " " << v[2] << " " << v[3] << " " << v[4] << " " << v[5] << " ";
 
       std::cout << "v: " << v.t() << std::endl;
 
-      std::cout << "|| s - s* || = "<< ( task.getError() ).sumSquare() << std::endl;
+      std::cout << "|| s - s* || = " << (task.getError()).sumSquare() << std::endl;
 
       // Save feature error (s-s*) for the 4 feature points. For each feature
-      // point, we have 2 errors (along x and y axis).  This error is expressed
-      // in meters in the camera frame
-      flog << ( task.getError() ).t() << " ";// s-s* for point 4
-      std::cout << "|| s - s* || = " << ( task.getError() ).sumSquare() <<std::endl ;
+      // point, we have 2 errors (along x and y axis).  This error is
+      // expressed in meters in the camera frame
+      flog << (task.getError()).t() << " "; // s-s* for point 4
+      std::cout << "|| s - s* || = " << (task.getError()).sumSquare() << std::endl;
 
       // Save current visual feature s = (rho,theta)
-      for (i = 0 ; i < 4 ; i++) {
-        flog << p[i].get_rho() << " " <<  p[i].get_theta() << " ";
+      for (i = 0; i < 4; i++) {
+        flog << p[i].get_rho() << " " << p[i].get_theta() << " ";
       }
       // Save current position of the points
-      for (i = 0 ; i < 4 ; i++) {
-        flog << point[i].get_x() << " " <<  point[i].get_y() << " ";
+      for (i = 0; i < 4; i++) {
+        flog << point[i].get_x() << " " << point[i].get_y() << " ";
       }
       flog << std::endl;
 
       if (iter == 1) {
         vpImagePoint ip;
-        ip.set_i( 10 );
-        ip.set_j( 10 );
+        ip.set_i(10);
+        ip.set_j(10);
 
         std::cout << "\nClick in the internal camera view to continue..." << std::endl;
-        vpDisplay::displayText(Iint, ip,
-                               "A click to continue...",vpColor::red);
+        vpDisplay::displayText(Iint, ip, "A click to continue...", vpColor::red);
         vpDisplay::flush(Iint);
         vpDisplay::getClick(Iint);
       }
-
     }
 
-
-    flog.close() ; // Close the log file
+    flog.close(); // Close the log file
 
     // Display task information
-    task.print() ;
+    task.print();
 
     // Kill the task
     task.kill();
 
-    std::cout <<"Final robot position with respect to the object frame:\n";
+    std::cout << "Final robot position with respect to the object frame:\n";
     cMo.print();
 
     if (opt_display && opt_click_allowed) {
       // suppressed for automate test
       std::cout << "\n\nClick in the internal view to end..." << std::endl;
-      vpDisplay::getClick(Iint) ;
+      vpDisplay::getClick(Iint);
     }
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
     return 1;
   }
 }
 #else
-int
-main()
-{
-  std::cout << "You do not have X11, GTK, GDI or OpenCV display functionalities..." << std::endl;
-}
+int main() { std::cout << "You do not have X11, GTK, GDI or OpenCV display functionalities..." << std::endl; }
 
 #endif
