@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -36,7 +37,6 @@
  *
  *****************************************************************************/
 
-
 /*!
   \example servoSimuPoint2DCamVelocity3.cpp
   Servo a point:
@@ -44,26 +44,26 @@
   - velocity computed in the camera frame,
   - no display.
 
-  wrt. servoSimuPoint2DCamVelocity1.cpp only the type of control law is modified. This
-  illustrates the need for Jacobian update and Twist transformation matrix
-  initialization, only the X coordinate is selected.
+  wrt. servoSimuPoint2DCamVelocity1.cpp only the type of control law is
+  modified. This illustrates the need for Jacobian update and Twist
+  transformation matrix initialization, only the X coordinate is selected.
 
   Only the X coordinate is selected (test the selection process).
 */
 
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 
-#include <visp3/visual_features/vpFeatureBuilder.h>
-#include <visp3/visual_features/vpFeaturePoint.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
 #include <visp3/core/vpMath.h>
 #include <visp3/io/vpParseArgv.h>
-#include <visp3/vs/vpServo.h>
 #include <visp3/robot/vpSimulatorCamera.h>
+#include <visp3/visual_features/vpFeatureBuilder.h>
+#include <visp3/visual_features/vpFeaturePoint.h>
+#include <visp3/vs/vpServo.h>
 
 // List of allowed command line options
-#define GETOPTARGS	"h"
+#define GETOPTARGS "h"
 
 void usage(const char *name, const char *badparam);
 bool getOptions(int argc, const char **argv);
@@ -111,15 +111,19 @@ Set the program options.
 bool getOptions(int argc, const char **argv)
 {
   const char *optarg_;
-  int	c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg_)) > 1) {
 
     switch (c) {
-    case 'h': usage(argv[0], NULL); return false; break;
+    case 'h':
+      usage(argv[0], NULL);
+      return false;
+      break;
 
     default:
       usage(argv[0], optarg_);
-      return false; break;
+      return false;
+      break;
     }
   }
 
@@ -134,25 +138,24 @@ bool getOptions(int argc, const char **argv)
   return true;
 }
 
-int
-main(int argc, const char ** argv)
+int main(int argc, const char **argv)
 {
   try {
     // Read the command line options
     if (getOptions(argc, argv) == false) {
-      exit (-1);
+      exit(-1);
     }
 
-    vpServo task ;
-    vpSimulatorCamera robot ;
+    vpServo task;
+    vpSimulatorCamera robot;
 
-    std::cout << std::endl ;
-    std::cout << "-------------------------------------------------------" << std::endl ;
-    std::cout << " Test program for vpServo "  <<std::endl ;
-    std::cout << " Eye-in-hand task control,  articular velocity are computed" << std::endl ;
-    std::cout << " Simulation " << std::endl ;
-    std::cout << " task : servo a point " << std::endl ;
-    std::cout << "-------------------------------------------------------" << std::endl ;
+    std::cout << std::endl;
+    std::cout << "-------------------------------------------------------" << std::endl;
+    std::cout << " Test program for vpServo " << std::endl;
+    std::cout << " Eye-in-hand task control,  articular velocity are computed" << std::endl;
+    std::cout << " Simulation " << std::endl;
+    std::cout << " task : servo a point " << std::endl;
+    std::cout << "-------------------------------------------------------" << std::endl;
     std::cout << std::endl;
 
     // sets the initial camera location
@@ -168,79 +171,77 @@ main(int argc, const char ** argv)
     // sets the point coordinates in the world frame
     vpPoint point(0, 0, 0);
 
-    // computes the point coordinates in the camera frame and its 2D coordinates
+    // computes the point coordinates in the camera frame and its 2D
+    // coordinates
     point.track(cMo);
 
     // sets the current position of the visual feature
     vpFeaturePoint p;
-    vpFeatureBuilder::create(p,point);  //retrieve x,y and Z of the vpPoint structure
+    vpFeatureBuilder::create(p, point); // retrieve x,y and Z of the vpPoint structure
 
     // sets the desired position of the visual feature
     vpFeaturePoint pd;
-    pd.buildFrom(0,0,1); // buildFrom(x,y,Z) ;
+    pd.buildFrom(0, 0, 1); // buildFrom(x,y,Z) ;
 
     // define the task
     // - we want an eye-in-hand control law
     // - articular velocity are computed
-    task.setServo(vpServo::EYEINHAND_L_cVe_eJe) ;
+    task.setServo(vpServo::EYEINHAND_L_cVe_eJe);
 
     // Set the position of the camera in the end-effector frame
-    vpHomogeneousMatrix cMe ;
-    vpVelocityTwistMatrix cVe(cMe) ;
-    task.set_cVe(cVe) ;
+    vpHomogeneousMatrix cMe;
+    vpVelocityTwistMatrix cVe(cMe);
+    task.set_cVe(cVe);
 
     // Set the Jacobian (expressed in the end-effector frame)
-    vpMatrix eJe ;
-    robot.get_eJe(eJe) ;
-    task.set_eJe(eJe) ;
+    vpMatrix eJe;
+    robot.get_eJe(eJe);
+    task.set_eJe(eJe);
 
     // we want to see a point on a point
-    task.addFeature(p,pd, vpFeaturePoint::selectX()) ;
+    task.addFeature(p, pd, vpFeaturePoint::selectX());
 
     // set the gain
-    task.setLambda(1) ;
+    task.setLambda(1);
 
     // Display task information
-    task.print() ;
+    task.print();
 
-    unsigned int iter=0 ;
+    unsigned int iter = 0;
     // loop
-    while(iter++ < 100)
-    {
-      std::cout << "---------------------------------------------" << iter <<std::endl ;
-      vpColVector v ;
+    while (iter++ < 100) {
+      std::cout << "---------------------------------------------" << iter << std::endl;
+      vpColVector v;
 
       // Set the Jacobian (expressed in the end-effector frame)
       // since q is modified eJe is modified
-      robot.get_eJe(eJe) ;
-      task.set_eJe(eJe) ;
+      robot.get_eJe(eJe);
+      task.set_eJe(eJe);
 
       // get the robot position
-      robot.getPosition(wMc) ;
+      robot.getPosition(wMc);
       // Compute the position of the camera wrt the object frame
       cMo = wMc.inverse() * wMo;
 
       // new point position
-      point.track(cMo) ;
-      vpFeatureBuilder::create(p,point)  ;  //retrieve x,y and Z of the vpPoint structure
+      point.track(cMo);
+      vpFeatureBuilder::create(p, point); // retrieve x,y and Z of the vpPoint structure
 
       // compute the control law
-      v = task.computeControlLaw() ;
+      v = task.computeControlLaw();
 
       // send the camera velocity to the controller
-      robot.setVelocity(vpRobot::CAMERA_FRAME, v) ;
+      robot.setVelocity(vpRobot::CAMERA_FRAME, v);
 
-      std::cout << "|| s - s* || = " << ( task.getError() ).sumSquare() <<std::endl ;
+      std::cout << "|| s - s* || = " << (task.getError()).sumSquare() << std::endl;
     }
 
     // Display task information
-    task.print() ;
+    task.print();
     task.kill();
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
     return 1;
   }
 }
-
