@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -36,7 +37,6 @@
  *
  *****************************************************************************/
 
-
 /*!
   \example servoSimuPoint2DhalfCamVelocity1.cpp
   Simulation of a 2 1/2 D visual servoing (theta U):
@@ -47,23 +47,22 @@
 
 */
 
-
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 
+#include <visp3/core/vpHomogeneousMatrix.h>
+#include <visp3/core/vpMath.h>
+#include <visp3/core/vpPoint.h>
+#include <visp3/io/vpParseArgv.h>
+#include <visp3/robot/vpSimulatorCamera.h>
 #include <visp3/visual_features/vpFeatureBuilder.h>
 #include <visp3/visual_features/vpFeaturePoint.h>
 #include <visp3/visual_features/vpFeatureThetaU.h>
 #include <visp3/visual_features/vpGenericFeature.h>
-#include <visp3/core/vpHomogeneousMatrix.h>
-#include <visp3/core/vpMath.h>
-#include <visp3/io/vpParseArgv.h>
-#include <visp3/core/vpPoint.h>
 #include <visp3/vs/vpServo.h>
-#include <visp3/robot/vpSimulatorCamera.h>
 
 // List of allowed command line options
-#define GETOPTARGS	"h"
+#define GETOPTARGS "h"
 
 void usage(const char *name, const char *badparam);
 bool getOptions(int argc, const char **argv);
@@ -94,7 +93,7 @@ OPTIONS:                                               Default\n\
      Print the help.\n");
 
   if (badparam) {
-    fprintf(stderr, "ERROR: \n" );
+    fprintf(stderr, "ERROR: \n");
     fprintf(stderr, "\nBad parameter [%s]\n", badparam);
   }
 }
@@ -112,15 +111,19 @@ Set the program options.
 bool getOptions(int argc, const char **argv)
 {
   const char *optarg_;
-  int	c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg_)) > 1) {
 
     switch (c) {
-    case 'h': usage(argv[0], NULL); return false; break;
+    case 'h':
+      usage(argv[0], NULL);
+      return false;
+      break;
 
     default:
       usage(argv[0], optarg_);
-      return false; break;
+      return false;
+      break;
     }
   }
 
@@ -135,44 +138,41 @@ bool getOptions(int argc, const char **argv)
   return true;
 }
 
-int
-main(int argc, const char ** argv)
+int main(int argc, const char **argv)
 {
   try {
     // Read the command line options
     if (getOptions(argc, argv) == false) {
-      exit (-1);
+      exit(-1);
     }
 
-    vpServo task ;
-    vpSimulatorCamera robot ;
+    vpServo task;
+    vpSimulatorCamera robot;
 
-    std::cout << std::endl ;
-    std::cout << "-------------------------------------------------------" << std::endl ;
-    std::cout << " Test program for vpServo "  <<std::endl ;
-    std::cout << " task :  2 1/2 D visual servoing " << std::endl ;
-    std::cout << "-------------------------------------------------------" << std::endl ;
-    std::cout << std::endl ;
+    std::cout << std::endl;
+    std::cout << "-------------------------------------------------------" << std::endl;
+    std::cout << " Test program for vpServo " << std::endl;
+    std::cout << " task :  2 1/2 D visual servoing " << std::endl;
+    std::cout << "-------------------------------------------------------" << std::endl;
+    std::cout << std::endl;
 
     // sets the initial camera location
-    vpPoseVector c_r_o(0.1,0.2,2,
-                       vpMath::rad(20), vpMath::rad(10),  vpMath::rad(50)
-                       ) ;
+    vpPoseVector c_r_o(0.1, 0.2, 2, vpMath::rad(20), vpMath::rad(10), vpMath::rad(50));
 
-    vpHomogeneousMatrix cMo(c_r_o) ;
+    vpHomogeneousMatrix cMo(c_r_o);
     // Compute the position of the object in the world frame
     vpHomogeneousMatrix wMc, wMo;
-    robot.getPosition(wMc) ;
+    robot.getPosition(wMc);
     wMo = wMc * cMo;
 
     // sets the desired camera location
-    vpPoseVector cd_r_o(0,0,1,
-                        vpMath::rad(0),vpMath::rad(0),vpMath::rad(0)) ;
+    vpPoseVector cd_r_o(0, 0, 1, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
     vpHomogeneousMatrix cdMo(cd_r_o);
 
     // sets the point coordinates in the world frame
     vpPoint point(0, 0, 0);
-    // computes the point coordinates in the camera frame and its 2D coordinates
+    // computes the point coordinates in the camera frame and its 2D
+    // coordinates
     point.track(cMo);
 
     vpPoint pointd(0, 0, 0);
@@ -181,29 +181,29 @@ main(int argc, const char ** argv)
     // 1st feature (x,y)
     // want to it at (0,0)
     vpFeaturePoint p;
-    vpFeatureBuilder::create(p,point);
+    vpFeatureBuilder::create(p, point);
 
     vpFeaturePoint pd;
-    vpFeatureBuilder::create(pd,pointd);
+    vpFeatureBuilder::create(pd, pointd);
 
     //------------------------------------------------------------------
     // 2nd feature (Z)
     // not necessary to project twice (reuse p)
-    vpFeaturePoint3D Z ;
-    vpFeatureBuilder::create(Z,point)  ;  //retrieve x,y and Z of the vpPoint structure
+    vpFeaturePoint3D Z;
+    vpFeatureBuilder::create(Z, point); // retrieve x,y and Z of the vpPoint structure
 
     // want to see it one meter away (here again use pd)
-    vpFeaturePoint3D Zd ;
-    vpFeatureBuilder::create(Zd,pointd)  ;  //retrieve x,y and Z of the vpPoint structure
+    vpFeaturePoint3D Zd;
+    vpFeatureBuilder::create(Zd, pointd); // retrieve x,y and Z of the vpPoint structure
 
     //------------------------------------------------------------------
     // 3rd feature ThetaU
     // compute the rotation that the camera has to achieve
-    vpHomogeneousMatrix cdMc ;
-    cdMc = cdMo*cMo.inverse() ;
+    vpHomogeneousMatrix cdMc;
+    cdMc = cdMo * cMo.inverse();
 
-    vpFeatureThetaU tu(vpFeatureThetaU::cdRc) ;
-    tu.buildFrom(cdMc) ;
+    vpFeatureThetaU tu(vpFeatureThetaU::cdRc);
+    tu.buildFrom(cdMc);
 
     // sets the desired rotation (always zero !)
     // since s is the rotation that the camera has to achieve
@@ -212,55 +212,52 @@ main(int argc, const char ** argv)
     // define the task
     // - we want an eye-in-hand control law
     // - robot is controlled in the camera frame
-    task.setServo(vpServo::EYEINHAND_CAMERA) ;
+    task.setServo(vpServo::EYEINHAND_CAMERA);
 
-    task.addFeature(p,pd) ;
-    task.addFeature(Z,Zd,vpFeaturePoint3D::selectZ()) ;
-    task.addFeature(tu) ;
+    task.addFeature(p, pd);
+    task.addFeature(Z, Zd, vpFeaturePoint3D::selectZ());
+    task.addFeature(tu);
 
     // set the gain
-    task.setLambda(1) ;
+    task.setLambda(1);
 
     // Display task information
-    task.print() ;
+    task.print();
 
-    unsigned int iter=0 ;
+    unsigned int iter = 0;
     // loop
-    while(iter++<200)
-    {
-      std::cout << "---------------------------------------------" << iter <<std::endl ;
-      vpColVector v ;
+    while (iter++ < 200) {
+      std::cout << "---------------------------------------------" << iter << std::endl;
+      vpColVector v;
 
       // get the robot position
-      robot.getPosition(wMc) ;
+      robot.getPosition(wMc);
       // Compute the position of the camera wrt the object frame
       cMo = wMc.inverse() * wMo;
 
       // update the feature
-      point.track(cMo) ;
-      vpFeatureBuilder::create(p,point)  ;
-      vpFeatureBuilder::create(Z,point)  ;
+      point.track(cMo);
+      vpFeatureBuilder::create(p, point);
+      vpFeatureBuilder::create(Z, point);
 
-      cdMc = cdMo*cMo.inverse() ;
-      tu.buildFrom(cdMc) ;
+      cdMc = cdMo * cMo.inverse();
+      tu.buildFrom(cdMc);
 
       // compute the control law
-      v = task.computeControlLaw() ;
+      v = task.computeControlLaw();
       // send the camera velocity to the controller ") ;
-      robot.setVelocity(vpRobot::CAMERA_FRAME, v) ;
+      robot.setVelocity(vpRobot::CAMERA_FRAME, v);
 
-      std::cout << "|| s - s* || = " << ( task.getError() ).sumSquare() <<std::endl ;
+      std::cout << "|| s - s* || = " << (task.getError()).sumSquare() << std::endl;
     }
 
     // Display task information
-    task.print() ;
+    task.print();
     task.kill();
-    std::cout << "Final camera location:\n " << cMo << std::endl ;
+    std::cout << "Final camera location:\n " << cMo << std::endl;
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
     return 1;
   }
 }
-
