@@ -3,9 +3,10 @@
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
  *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * ("GPL") version 2 as published by the Free Software Foundation.
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  * See the file LICENSE.txt at the root directory of this source
  * distribution for additional information about the GNU GPL.
  *
@@ -36,7 +37,6 @@
  *
  *****************************************************************************/
 
-
 /*!
   \example servoSimuPoint2DhalfCamVelocity3.cpp
   Simulation of a 2 1/2 D visual servoing (x,y, t,theta u_z)
@@ -46,23 +46,22 @@
   - no display.
 */
 
-
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 
+#include <visp3/core/vpHomogeneousMatrix.h>
+#include <visp3/core/vpMath.h>
+#include <visp3/core/vpPoint.h>
+#include <visp3/io/vpParseArgv.h>
+#include <visp3/robot/vpSimulatorCamera.h>
 #include <visp3/visual_features/vpFeatureBuilder.h>
 #include <visp3/visual_features/vpFeaturePoint.h>
 #include <visp3/visual_features/vpFeatureThetaU.h>
 #include <visp3/visual_features/vpGenericFeature.h>
-#include <visp3/core/vpHomogeneousMatrix.h>
-#include <visp3/core/vpMath.h>
-#include <visp3/io/vpParseArgv.h>
-#include <visp3/core/vpPoint.h>
 #include <visp3/vs/vpServo.h>
-#include <visp3/robot/vpSimulatorCamera.h>
 
 // List of allowed command line options
-#define GETOPTARGS	"h"
+#define GETOPTARGS "h"
 
 void usage(const char *name, const char *badparam);
 bool getOptions(int argc, const char **argv);
@@ -108,15 +107,19 @@ Set the program options.
 bool getOptions(int argc, const char **argv)
 {
   const char *optarg_;
-  int	c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg_)) > 1) {
 
     switch (c) {
-    case 'h': usage(argv[0], NULL); return false; break;
+    case 'h':
+      usage(argv[0], NULL);
+      return false;
+      break;
 
     default:
       usage(argv[0], optarg_);
-      return false; break;
+      return false;
+      break;
     }
   }
 
@@ -131,20 +134,19 @@ bool getOptions(int argc, const char **argv)
   return true;
 }
 
-int
-main(int argc, const char ** argv)
+int main(int argc, const char **argv)
 {
   try {
     // Read the command line options
     if (getOptions(argc, argv) == false) {
-      exit (-1);
+      exit(-1);
     }
 
-    std::cout << std::endl ;
-    std::cout << "-------------------------------------------------------" << std::endl ;
-    std::cout << " simulation of a 2 1/2 D visual servoing " << std::endl ;
-    std::cout << "-------------------------------------------------------" << std::endl ;
-    std::cout << std::endl ;
+    std::cout << std::endl;
+    std::cout << "-------------------------------------------------------" << std::endl;
+    std::cout << " simulation of a 2 1/2 D visual servoing " << std::endl;
+    std::cout << "-------------------------------------------------------" << std::endl;
+    std::cout << std::endl;
 
     // In this example we will simulate a visual servoing task.
     // In simulation, we have to define the scene frane Ro and the
@@ -152,35 +154,32 @@ main(int argc, const char ** argv)
     // The camera location is given by an homogenous matrix cMo that
     // describes the position of the camera in the scene frame.
 
-    vpServo task ;
+    vpServo task;
 
     // sets the initial camera location
     // we give the camera location as a size 6 vector (3 translations in meter
     // and 3 rotation (theta U representation)
-    vpPoseVector c_r_o(0.1,0.2,2,
-                       vpMath::rad(20), vpMath::rad(10),  vpMath::rad(50)
-                       ) ;
+    vpPoseVector c_r_o(0.1, 0.2, 2, vpMath::rad(20), vpMath::rad(10), vpMath::rad(50));
 
     // this pose vector is then transformed in a 4x4 homogeneous matrix
-    vpHomogeneousMatrix cMo(c_r_o) ;
+    vpHomogeneousMatrix cMo(c_r_o);
 
     // We define a robot
     // The vpSimulatorCamera implements a simple moving that is juste defined
     // by its location cMo
-    vpSimulatorCamera robot ;
+    vpSimulatorCamera robot;
 
     // Compute the position of the object in the world frame
     vpHomogeneousMatrix wMc, wMo;
-    robot.getPosition(wMc) ;
+    robot.getPosition(wMc);
     wMo = wMc * cMo;
 
     // Now that the current camera position has been defined,
     // let us defined the defined camera location.
     // It is defined by cdMo
     // sets the desired camera location " ) ;
-    vpPoseVector cd_r_o(0,0,1,
-                        vpMath::rad(0),vpMath::rad(0),vpMath::rad(0)) ;
-    vpHomogeneousMatrix cdMo(cd_r_o) ;
+    vpPoseVector cd_r_o(0, 0, 1, vpMath::rad(0), vpMath::rad(0), vpMath::rad(0));
+    vpHomogeneousMatrix cdMo(cd_r_o);
 
     //----------------------------------------------------------------------
     // A 2 1/2 D visual servoing can be defined by
@@ -191,7 +190,6 @@ main(int argc, const char ** argv)
 
     // Let us now defined the current value of these features
 
-
     // since we simulate we have to define a 3D point that will
     // forward-projected to define the current position x,y of the
     // reference point
@@ -207,16 +205,17 @@ main(int argc, const char ** argv)
 
     //------------------------------------------------------------------
     // sets the point coordinates in the world frame
-    vpPoint P(0, 0, 0) ;
+    vpPoint P(0, 0, 0);
     // computes  the P coordinates in the camera frame and its
     // 2D coordinates cP and then p
-    // computes the point coordinates in the camera frame and its 2D coordinates
-    P.track(cMo) ;
+    // computes the point coordinates in the camera frame and its 2D
+    // coordinates
+    P.track(cMo);
 
     // We also defined (again by forward projection) the desired position
     // of this point according to the desired camera position
-    vpPoint Pd(0, 0, 0) ;
-    Pd.track(cdMo) ;
+    vpPoint Pd(0, 0, 0);
+    Pd.track(cdMo);
 
     // Nevertheless, a vpPoint is not a feature, this is just a "tracker"
     // from which the feature are built
@@ -226,33 +225,33 @@ main(int argc, const char ** argv)
 
     // for a point (x,y) Visp implements the vpFeaturePoint class.
     // we no defined a feature for x,y (and for (x*,y*))
-    vpFeaturePoint p,pd ;
+    vpFeaturePoint p, pd;
 
     // and we initialized the vector s=(x,y) of p from the tracker P
     // Z coordinates in p is also initialized, it will be used to compute
     // the interaction matrix
-    vpFeatureBuilder::create(p,P)  ;
-    vpFeatureBuilder::create(pd,Pd)  ;
+    vpFeatureBuilder::create(p, P);
+    vpFeatureBuilder::create(pd, Pd);
 
     // This visual has to be regulated to zero
 
     //------------------------------------------------------------------
     // 2nd feature ThetaUz and 3rd feature t
-    // The thetaU feature is defined, tu represents the rotation that the camera
-    // has to realized. t the translation.
-    // the complete displacement is then defined by:
+    // The thetaU feature is defined, tu represents the rotation that the
+    // camera has to realized. t the translation. the complete displacement is
+    // then defined by:
     //------------------------------------------------------------------
-    vpHomogeneousMatrix cdMc ;
+    vpHomogeneousMatrix cdMc;
     // compute the rotation that the camera has to achieve
-    cdMc = cdMo*cMo.inverse() ;
+    cdMc = cdMo * cMo.inverse();
 
     // from this displacement, we extract the rotation cdRc represented by
     // the angle theta and the rotation axis u
-    vpFeatureThetaU tuz(vpFeatureThetaU::cdRc) ;
-    tuz.buildFrom(cdMc) ;
+    vpFeatureThetaU tuz(vpFeatureThetaU::cdRc);
+    tuz.buildFrom(cdMc);
     // And the translations
-    vpFeatureTranslation t(vpFeatureTranslation::cdMc) ;
-    t.buildFrom(cdMc) ;
+    vpFeatureTranslation t(vpFeatureTranslation::cdMc);
+    t.buildFrom(cdMc);
 
     // This visual has to be regulated to zero
 
@@ -267,15 +266,15 @@ main(int argc, const char ** argv)
     // - we want an eye-in-hand control law
     // - robot is controlled in the camera frame
     //  we choose to control the robot in the camera frame
-    task.setServo(vpServo::EYEINHAND_CAMERA) ;
+    task.setServo(vpServo::EYEINHAND_CAMERA);
     // Interaction matrix is computed with the current value of s
-    task.setInteractionMatrixType(vpServo::CURRENT) ;
+    task.setInteractionMatrixType(vpServo::CURRENT);
 
     // we build the task by "stacking" the visual feature
     // previously defined
-    task.addFeature(t) ;
-    task.addFeature(p,pd) ;
-    task.addFeature(tuz,vpFeatureThetaU::TUz) ; //selection of TUz
+    task.addFeature(t);
+    task.addFeature(p, pd);
+    task.addFeature(tuz, vpFeatureThetaU::TUz); // selection of TUz
 
     // addFeature(X,Xd) means X should be regulated to Xd
     // addFeature(X) means that X should be regulated to 0
@@ -283,52 +282,49 @@ main(int argc, const char ** argv)
     // (otherwise, it will results in an error at exectution level)
 
     // set the gain
-    task.setLambda(1) ;
+    task.setLambda(1);
 
     // Display task information " ) ;
-    task.print() ;
+    task.print();
     //------------------------------------------------------------------
     // An now the closed loop
 
-    unsigned int iter=0 ;
+    unsigned int iter = 0;
     // loop
-    while(iter++<200)
-    {
-      std::cout << "---------------------------------------------" << iter <<std::endl ;
-      vpColVector v ;
+    while (iter++ < 200) {
+      std::cout << "---------------------------------------------" << iter << std::endl;
+      vpColVector v;
 
       // get the robot position
-      robot.getPosition(wMc) ;
+      robot.getPosition(wMc);
       // Compute the position of the camera wrt the object frame
       cMo = wMc.inverse() * wMo;
 
       // update the feature
-      P.track(cMo) ;
-      vpFeatureBuilder::create(p,P)  ;
+      P.track(cMo);
+      vpFeatureBuilder::create(p, P);
 
-      cdMc = cdMo*cMo.inverse() ;
-      tuz.buildFrom(cdMc) ;
-      t.buildFrom(cdMc) ;
+      cdMc = cdMo * cMo.inverse();
+      tuz.buildFrom(cdMc);
+      t.buildFrom(cdMc);
 
       // compute the control law: v = -lambda L^+(s-sd)
-      v = task.computeControlLaw() ;
+      v = task.computeControlLaw();
 
       // send the camera velocity to the controller
-      robot.setVelocity(vpRobot::CAMERA_FRAME, v) ;
+      robot.setVelocity(vpRobot::CAMERA_FRAME, v);
 
-      std::cout << "|| s - s* || = " << ( task.getError() ).sumSquare() <<std::endl ;
+      std::cout << "|| s - s* || = " << (task.getError()).sumSquare() << std::endl;
     }
 
     // Display task information
-    task.print() ;
+    task.print();
     task.kill();
     // Final camera location
-    std::cout << "Final camera location: \n" << cMo << std::endl ;
+    std::cout << "Final camera location: \n" << cMo << std::endl;
     return 0;
-  }
-  catch(vpException &e) {
+  } catch (vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
     return 1;
   }
 }
-
